@@ -3,10 +3,11 @@
  *
  * authors: Tomasz Mrugalski <thomson@klub.com.pl>
  *          Marek Senderski <msend@o2.pl>
+ * changes: Grzegorz Pluto <g.pluto(at)u-r-b-a-n(dot)pl>
  *
  * released under GNU GPL v2 only licence
  *
- * $Id: AddrIA.h,v 1.10 2008-11-11 21:55:27 thomson Exp $
+ * $Id: AddrIA.h,v 1.11 2009-03-24 23:17:16 thomson Exp $
  *
  */
 
@@ -28,8 +29,15 @@ using namespace std;
 class TAddrIA
 {
   public:
+    typedef enum
+    {
+	TYPE_IA,
+	TYPE_TA,
+	TYPE_PD
+    } TIAType;
+
     friend ostream & operator<<(ostream & strum,TAddrIA &x);
-    TAddrIA(int iface, SmartPtr<TIPv6Addr> addr, SmartPtr<TDUID> duid, 
+    TAddrIA(int iface, TIAType mode, SPtr<TIPv6Addr> addr, SPtr<TDUID> duid, 
 	    unsigned long T1, unsigned long T2,unsigned long ID);
     ~TAddrIA();
 
@@ -38,6 +46,7 @@ class TAddrIA
     void setState(enum EState state);
     void setT1(unsigned long T1);
     void setT2(unsigned long T2);
+    //void reset(unsigned long id);
     void reset();
     unsigned long getT1();
     unsigned long getT2();
@@ -47,17 +56,17 @@ class TAddrIA
     int getIface();
 
     //---Server's DUID---
-    void setDUID(SmartPtr<TDUID> duid);
-    SmartPtr<TDUID> getDUID();
+    void setDUID(SPtr<TDUID> duid);
+    SPtr<TDUID> getDUID();
 
     //---Contact with server using Unicast/Multicast---
-    void setUnicast(SmartPtr<TIPv6Addr> addr);
+    void setUnicast(SPtr<TIPv6Addr> addr);
     void setMulticast();
-    SmartPtr<TIPv6Addr> getSrvAddr();
+    SPtr<TIPv6Addr> getSrvAddr();
 
     //--- address list related methods---
-    void addAddr(SmartPtr<TAddrAddr> x);
-    void addAddr(SmartPtr<TIPv6Addr> addr, unsigned long pref, unsigned long valid);
+    void addAddr(SPtr<TAddrAddr> x);
+    void addAddr(SPtr<TIPv6Addr> addr, unsigned long pref, unsigned long valid);
     void addAddr(SPtr<TIPv6Addr> addr, unsigned long pref, unsigned long valid, int prefix);
     int getAddrCount();
 
@@ -66,18 +75,17 @@ class TAddrIA
     SPtr<TAddrPrefix> getPrefix();
 
     void addPrefix(SPtr<TAddrPrefix> x);
-    void addPrefix(SPtr<TIPv6Addr> addr, unsigned long pref, unsigned long valid,
-		   int length);
+    void addPrefix(SPtr<TIPv6Addr> addr, unsigned long pref, unsigned long valid, int length);
     int getPrefixCount();
     bool delPrefix(SPtr<TAddrPrefix> x);
     bool delPrefix(SPtr<TIPv6Addr> x);
 
     // --- address management ---
     void firstAddr();
-    SmartPtr<TAddrAddr> getAddr();
-    SmartPtr<TAddrAddr> getAddr(SmartPtr<TIPv6Addr> addr);
+    SPtr<TAddrAddr> getAddr();
+    SPtr<TAddrAddr> getAddr(SPtr<TIPv6Addr> addr);
     int countAddr();
-    int delAddr(SmartPtr<TIPv6Addr> addr);
+    int delAddr(SPtr<TIPv6Addr> addr);
     
     // timestamp
     void setTimestamp(unsigned long ts);
@@ -87,7 +95,6 @@ class TAddrIA
     unsigned long getPrefTimeout();
     unsigned long getValidTimeout();
     unsigned long getMaxValidTimeout();
-    unsigned long getMaxValid();
     unsigned long getTimestamp();
     
     //---tentative---
@@ -114,17 +121,19 @@ private:
 
     unsigned long Timestamp; // timestamp of last IA refresh (renew/rebind/confirm etc.)
 
-    SmartPtr<TDUID> DUID;
+    SPtr<TDUID> DUID;
 
     // Server which maintains this IA is connected by unicast or multicast
     bool Unicast;
-    SmartPtr<TIPv6Addr> SrvAddr;
+    SPtr<TIPv6Addr> SrvAddr;
 
     // Iface ID
     int Iface;
 
     SPtr<TIPv6Addr> fqdnDnsServer; // DNS Updates was performed to that server
     SPtr<TFQDN> fqdn;              // this FQDN object was used to perform update
+
+    TIAType Type; // type of this IA (IA, TA or PD)
 };
 
 #endif 
