@@ -6,7 +6,7 @@
  *
  * released under GNU GPL v2 only licence
  *
- * $Id: ClntCfgIA.h,v 1.9 2008-08-29 00:07:27 thomson Exp $
+ * $Id: ClntCfgIA.h,v 1.10 2009-03-24 23:17:17 thomson Exp $
  */
 
 class TClntCfgIA;
@@ -32,29 +32,30 @@ class TClntCfgIA
     unsigned long getT1();
     unsigned long getT2();
 
-    void setOptions(SmartPtr<TClntParsGlobalOpt> opt);
+    void setOptions(SPtr<TClntParsGlobalOpt> opt);
 
     void firstAddr();
-    SmartPtr<TClntCfgAddr> getAddr();
+    SPtr<TClntCfgAddr> getAddr();
     long countAddr();
-    void addAddr(SmartPtr<TClntCfgAddr> addr);
+    void addAddr(SPtr<TClntCfgAddr> addr);
 
     TClntCfgIA();
-    TClntCfgIA(SmartPtr<TClntCfgIA> right, long iAID);
+    TClntCfgIA(SPtr<TClntCfgIA> right, long iAID);
 
+    void reset();
     void setState(enum EState state);
     enum EState getState();
     bool getAddrParams();
-    
+
   private:
     unsigned long IAID;
     unsigned long T1;
     unsigned long T2;
-    
-    EState State;	
+    EState State;
     List(TClntCfgAddr) ClntCfgAddrLst;
+    static long newID();
 
-    bool AddrParams;
+    bool AddrParams;     /// experimental address parameters feature
 };
 
 #endif 
