@@ -30,38 +30,45 @@ class ClntParser;
 #include "KeyList.h"
 #endif
 
+#define ClntCfgMgr() (TClntCfgMgr::instance())
+
 class TClntCfgMgr : public TCfgMgr
 {
     friend ostream & operator<<(ostream &strum, TClntCfgMgr &x);
+ private:
+    TClntCfgMgr(const std::string cfgFile);
+
  public:
-    TClntCfgMgr(SmartPtr<TClntIfaceMgr> IfaceMgr, const string cfgFile);
+    static TClntCfgMgr & instance();
+    static void instanceCreate(const std::string cfgFile);
     ~TClntCfgMgr();
     
     // --- Iface related ---
-    SmartPtr<TClntCfgIA> getIA(long IAID);
-    SmartPtr<TClntCfgPD> getPD(long IAID);
-    SmartPtr<TClntCfgIface> getIface();
-    SmartPtr<TClntCfgIface> getIface(int id);
+    SPtr<TClntCfgIA> getIA(long IAID);
+    SPtr<TClntCfgPD> getPD(long IAID);
+    SPtr<TClntCfgIface> getIface();
+    SPtr<TClntCfgIface> getIface(int id);
     void firstIface();
-    void addIface(SmartPtr<TClntCfgIface> x);
+    void addIface(SPtr<TClntCfgIface> x);
     void makeInactiveIface(int ifindex, bool inactive);
     int countIfaces();
     void dump();
     
+    void setReconfigure(bool enable);
     bool getReconfigure();
     
     //IA related
     bool setIAState(int iface, int iaid, enum EState state);
     int countAddrForIA(long IAID);
     
-    SmartPtr<TClntCfgIface> getIfaceByIAID(int iaid);
+    SPtr<TClntCfgIface> getIfaceByIAID(int iaid);
     bool isDone();
 
     DigestTypes getDigest();
     void setDigest(DigestTypes value);
 
-    string getScriptsDir();
-    bool getNotifyScripts();
+    void setScript(std::string script) { ScriptName = script; }
+    string getScript() { return ScriptName; }
 
     bool anonInfRequest();
     bool insistMode();
@@ -77,48 +84,52 @@ class TClntCfgMgr : public TCfgMgr
     uint32_t getAAASPI();
     List(DigestTypes) getAuthAcceptMethods();
     bool getAuthEnabled();
-    SmartPtr<KeyList> AuthKeys;
+    SPtr<KeyList> AuthKeys;
+#endif
+
+#ifdef MOD_REMOTE_AUTOCONF
+    void setRemoteAutoconf(bool enable);
+    bool getRemoteAutoconf();
 #endif
 
     bool getFQDNFlagS();
-    bool getMappingPrefix();
 
     bool useConfirm();
-
-    int tunnelMode(); // returns vendor-id
-
 private:
     bool setGlobalOptions(ClntParser * parser);
     bool validateConfig();
-    bool validateIface(SmartPtr<TClntCfgIface> iface);
-    bool validateIA(SmartPtr<TClntCfgIface> ptrIface, SmartPtr<TClntCfgIA> ptrIA);
-    bool validateAddr(SmartPtr<TClntCfgIface> ptrIface, 
-		      SmartPtr<TClntCfgIA> ptrIA,
-		      SmartPtr<TClntCfgAddr> ptrAddr);
+    bool validateIface(SPtr<TClntCfgIface> iface);
+    bool validateIA(SPtr<TClntCfgIface> ptrIface, SPtr<TClntCfgIA> ptrIA);
+    bool validateAddr(SPtr<TClntCfgIface> ptrIface, 
+		      SPtr<TClntCfgIA> ptrIA,
+		      SPtr<TClntCfgAddr> ptrAddr);
     bool parseConfigFile(string cfgFile);
     bool matchParsedSystemInterfaces(ClntParser *parser);
 
-    SmartPtr<TClntIfaceMgr> IfaceMgr;
     List(TClntCfgIface) ClntCfgIfaceLst;
     List(TClntCfgIface) InactiveLst;
-    DigestTypes Digest;
-    string ScriptsDir;
-    bool NotifyScripts;
+    string ScriptName;
 
     bool AnonInfRequest;
     bool InsistMode;
     bool InactiveMode;
     bool UseConfirm;
+    bool Reconfigure;
 
+    DigestTypes Digest;
 #ifndef MOD_DISABLE_AUTH
     bool AuthEnabled;
     List(DigestTypes) AuthAcceptMethods;
     uint32_t AAASPI;
 #endif
 
+#ifdef MOD_REMOTE_AUTOCONF
+    bool RemoteAutoconf;
+#endif
+
     bool FQDNFlagS; // S bit in the FQDN option
-    bool MappingPrefix;
-    int  TunnelMode;
+
+    static TClntCfgMgr * Instance;
 };
 
 typedef bool HardcodedCfgFunc(TClntCfgMgr *cfgMgr, string params);
