@@ -28,11 +28,15 @@
 #include "ClntCfgTA.h"
 #include "ClntCfgPD.h"
 #include "ClntOptVendorSpec.h"
-#include "CfgMgr.h"
+#include "ClntCfgMgr.h"
 #include "Logger.h"
+#include "OptGeneric.h"
+#include "OptAddr.h"
+#include "OptAddrLst.h"
+#include "OptString.h"
 
 using namespace std;
-    
+
 #define YY_USE_CLASS
 #define YY_ClntParser_MEMBERS  yyFlexLexer * lex;                                          \
 /*List of options in scope stack,the most fresh is last in the list*/       \
@@ -47,17 +51,15 @@ List(TClntCfgAddr)  ClntCfgAddrLst;                                         \
 List(DigestTypes)   DigestLst;                                              \
 /*Pointer to list which should contain either rejected servers or */        \
 /*preffered servers*/                                                       \
-TContainer<SmartPtr<TStationID> > PresentStationLst;                        \
-TContainer<SmartPtr<TIPv6Addr> > PresentAddrLst;                            \
-TContainer<SmartPtr<string> > PresentStringLst;                             \
-List(TClntOptVendorSpec) VendorSpec;					    \
-SPtr<TClntOptVendorSpec> TunnelMode;                                        \
-/*method check whether interface with id=ifaceNr has been */                \
-/*already declared */                                                       \
-bool CheckIsIface(int ifaceNr);                                             \
-/* method check if interface with id=ifaceName has been already declared */ \
-bool CheckIsIface(string ifaceName);                                        \
-void StartIfaceDeclaration();                                               \
+List(TStationID) PresentStationLst;		                            \
+List(TIPv6Addr) PresentAddrLst;			                            \
+List(TClntCfgPrefix) PrefixLst;                                             \
+List(string) PresentStringLst;	                                            \
+List(TOptVendorSpecInfo) VendorSpec;					    \
+bool IfaceDefined(int ifaceNr);                                             \
+bool IfaceDefined(string ifaceName);                                        \
+bool StartIfaceDeclaration(string ifaceName);                               \
+bool StartIfaceDeclaration(int ifindex);                                    \
 bool EndIfaceDeclaration();                                                 \
 void EmptyIface();                                                          \
 void StartIADeclaration(bool aggregation);                                  \
@@ -66,6 +68,7 @@ void StartPDDeclaration();                                                  \
 bool EndPDDeclaration();                                                    \
 void EmptyIA();                                                             \
 void EmptyAddr();                                                           \
+TClntCfgMgr * CfgMgr;                                                       \
 bool iaidSet;                                                               \
 unsigned int iaid;                                                          \
 virtual ~ClntParser();                                                      \
@@ -79,19 +82,18 @@ SPtr<TDUID> DUIDEnterpriseID;
     ParserOptStack.getFirst()->setIAIDCnt(1);                               \
     ParserOptStack.getLast();                                               \
     DUIDType = DUID_TYPE_NOT_DEFINED;                                       \
-    DUIDEnterpriseID = 0;                                                   \
-    TunnelMode = 0;
+    DUIDEnterpriseID = 0;
 
-#line 81 "ClntParser.y"
-typedef union    
+#line 83 "ClntParser.y"
+typedef union
 {
-    int ival;    
-    char *strval;  
-    struct SDuid  {      
-        int length;    
-        char* duid;  
-    } duidval;  
-    char addrval[16];  
+    int ival;
+    char *strval;
+    struct SDuid  {
+	int length;
+	char* duid;
+    } duidval;
+    char addrval[16];
 } yy_ClntParser_stype;
 #define YY_ClntParser_STYPE yy_ClntParser_stype
 
@@ -156,6 +158,7 @@ typedef union
 #ifndef YY_ClntParser_DEBUG
 
  #line 71 "../bison++/bison.h"
+#define YY_ClntParser_DEBUG 1
 
 #line 71 "../bison++/bison.h"
 /* YY_ClntParser_DEBUG */
@@ -279,54 +282,63 @@ typedef
 #define	NISP_DOMAIN_	272
 #define	FQDN_	273
 #define	FQDN_S_	274
-#define	LIFETIME_	275
-#define	VENDOR_SPEC_	276
-#define	IFACE_	277
-#define	NO_CONFIG_	278
-#define	REJECT_SERVERS_	279
-#define	PREFERRED_SERVERS_	280
-#define	IA_	281
-#define	TA_	282
-#define	IAID_	283
-#define	ADDRES_	284
-#define	IPV6ADDR_	285
-#define	WORKDIR_	286
-#define	RAPID_COMMIT_	287
-#define	OPTION_	288
-#define	SCRIPTS_DIR_	289
-#define	NOTIFY_SCRIPTS_	290
-#define	LOGNAME_	291
-#define	LOGLEVEL_	292
-#define	LOGMODE_	293
-#define	STRING_	294
-#define	HEXNUMBER_	295
-#define	INTNUMBER_	296
-#define	DUID_	297
-#define	STRICT_RFC_NO_ROUTING_	298
-#define	SKIP_CONFIRM_	299
-#define	PD_	300
-#define	DUID_TYPE_	301
-#define	DUID_TYPE_LLT_	302
-#define	DUID_TYPE_LL_	303
-#define	DUID_TYPE_EN_	304
-#define	AUTH_ENABLED_	305
-#define	AUTH_ACCEPT_METHODS_	306
-#define	DIGEST_NONE_	307
-#define	DIGEST_PLAIN_	308
-#define	DIGEST_HMAC_MD5_	309
-#define	DIGEST_HMAC_SHA1_	310
-#define	DIGEST_HMAC_SHA224_	311
-#define	DIGEST_HMAC_SHA256_	312
-#define	DIGEST_HMAC_SHA384_	313
-#define	DIGEST_HMAC_SHA512_	314
-#define	STATELESS_	315
-#define	ANON_INF_REQUEST_	316
-#define	INSIST_MODE_	317
-#define	INACTIVE_MODE_	318
-#define	EXPERIMENTAL_	319
-#define	ADDR_PARAMS_	320
-#define	MAPPING_PREFIX_	321
-#define	TUNNEL_MODE_	322
+#define	DDNS_PROTOCOL_	275
+#define	DDNS_TIMEOUT_	276
+#define	LIFETIME_	277
+#define	VENDOR_SPEC_	278
+#define	IFACE_	279
+#define	NO_CONFIG_	280
+#define	REJECT_SERVERS_	281
+#define	PREFERRED_SERVERS_	282
+#define	IA_	283
+#define	TA_	284
+#define	IAID_	285
+#define	ADDRESS_	286
+#define	NAME_	287
+#define	IPV6ADDR_	288
+#define	WORKDIR_	289
+#define	RAPID_COMMIT_	290
+#define	OPTION_	291
+#define	SCRIPT_	292
+#define	LOGNAME_	293
+#define	LOGLEVEL_	294
+#define	LOGMODE_	295
+#define	LOGCOLORS_	296
+#define	STRING_	297
+#define	HEXNUMBER_	298
+#define	INTNUMBER_	299
+#define	DUID_	300
+#define	STRICT_RFC_NO_ROUTING_	301
+#define	SKIP_CONFIRM_	302
+#define	PD_	303
+#define	PREFIX_	304
+#define	DUID_TYPE_	305
+#define	DUID_TYPE_LLT_	306
+#define	DUID_TYPE_LL_	307
+#define	DUID_TYPE_EN_	308
+#define	AUTH_ENABLED_	309
+#define	AUTH_ACCEPT_METHODS_	310
+#define	DIGEST_NONE_	311
+#define	DIGEST_PLAIN_	312
+#define	DIGEST_HMAC_MD5_	313
+#define	DIGEST_HMAC_SHA1_	314
+#define	DIGEST_HMAC_SHA224_	315
+#define	DIGEST_HMAC_SHA256_	316
+#define	DIGEST_HMAC_SHA384_	317
+#define	DIGEST_HMAC_SHA512_	318
+#define	STATELESS_	319
+#define	ANON_INF_REQUEST_	320
+#define	INSIST_MODE_	321
+#define	INACTIVE_MODE_	322
+#define	EXPERIMENTAL_	323
+#define	ADDR_PARAMS_	324
+#define	REMOTE_AUTOCONF_	325
+#define	AFTR_	326
+#define	ROUTING_	327
+#define	ADDRESS_LIST_	328
+#define	STRING_KEYWORD_	329
+#define	REQUEST_	330
+#define	RECONFIGURE_	331
 
 
 #line 169 "../bison++/bison.h"
@@ -392,6 +404,8 @@ static const int NIS_DOMAIN_;
 static const int NISP_DOMAIN_;
 static const int FQDN_;
 static const int FQDN_S_;
+static const int DDNS_PROTOCOL_;
+static const int DDNS_TIMEOUT_;
 static const int LIFETIME_;
 static const int VENDOR_SPEC_;
 static const int IFACE_;
@@ -401,16 +415,17 @@ static const int PREFERRED_SERVERS_;
 static const int IA_;
 static const int TA_;
 static const int IAID_;
-static const int ADDRES_;
+static const int ADDRESS_;
+static const int NAME_;
 static const int IPV6ADDR_;
 static const int WORKDIR_;
 static const int RAPID_COMMIT_;
 static const int OPTION_;
-static const int SCRIPTS_DIR_;
-static const int NOTIFY_SCRIPTS_;
+static const int SCRIPT_;
 static const int LOGNAME_;
 static const int LOGLEVEL_;
 static const int LOGMODE_;
+static const int LOGCOLORS_;
 static const int STRING_;
 static const int HEXNUMBER_;
 static const int INTNUMBER_;
@@ -418,6 +433,7 @@ static const int DUID_;
 static const int STRICT_RFC_NO_ROUTING_;
 static const int SKIP_CONFIRM_;
 static const int PD_;
+static const int PREFIX_;
 static const int DUID_TYPE_;
 static const int DUID_TYPE_LLT_;
 static const int DUID_TYPE_LL_;
@@ -438,8 +454,13 @@ static const int INSIST_MODE_;
 static const int INACTIVE_MODE_;
 static const int EXPERIMENTAL_;
 static const int ADDR_PARAMS_;
-static const int MAPPING_PREFIX_;
-static const int TUNNEL_MODE_;
+static const int REMOTE_AUTOCONF_;
+static const int AFTR_;
+static const int ROUTING_;
+static const int ADDRESS_LIST_;
+static const int STRING_KEYWORD_;
+static const int REQUEST_;
+static const int RECONFIGURE_;
 
 
 #line 212 "../bison++/bison.h"
@@ -465,54 +486,63 @@ static const int TUNNEL_MODE_;
 	,NISP_DOMAIN_=272
 	,FQDN_=273
 	,FQDN_S_=274
-	,LIFETIME_=275
-	,VENDOR_SPEC_=276
-	,IFACE_=277
-	,NO_CONFIG_=278
-	,REJECT_SERVERS_=279
-	,PREFERRED_SERVERS_=280
-	,IA_=281
-	,TA_=282
-	,IAID_=283
-	,ADDRES_=284
-	,IPV6ADDR_=285
-	,WORKDIR_=286
-	,RAPID_COMMIT_=287
-	,OPTION_=288
-	,SCRIPTS_DIR_=289
-	,NOTIFY_SCRIPTS_=290
-	,LOGNAME_=291
-	,LOGLEVEL_=292
-	,LOGMODE_=293
-	,STRING_=294
-	,HEXNUMBER_=295
-	,INTNUMBER_=296
-	,DUID_=297
-	,STRICT_RFC_NO_ROUTING_=298
-	,SKIP_CONFIRM_=299
-	,PD_=300
-	,DUID_TYPE_=301
-	,DUID_TYPE_LLT_=302
-	,DUID_TYPE_LL_=303
-	,DUID_TYPE_EN_=304
-	,AUTH_ENABLED_=305
-	,AUTH_ACCEPT_METHODS_=306
-	,DIGEST_NONE_=307
-	,DIGEST_PLAIN_=308
-	,DIGEST_HMAC_MD5_=309
-	,DIGEST_HMAC_SHA1_=310
-	,DIGEST_HMAC_SHA224_=311
-	,DIGEST_HMAC_SHA256_=312
-	,DIGEST_HMAC_SHA384_=313
-	,DIGEST_HMAC_SHA512_=314
-	,STATELESS_=315
-	,ANON_INF_REQUEST_=316
-	,INSIST_MODE_=317
-	,INACTIVE_MODE_=318
-	,EXPERIMENTAL_=319
-	,ADDR_PARAMS_=320
-	,MAPPING_PREFIX_=321
-	,TUNNEL_MODE_=322
+	,DDNS_PROTOCOL_=275
+	,DDNS_TIMEOUT_=276
+	,LIFETIME_=277
+	,VENDOR_SPEC_=278
+	,IFACE_=279
+	,NO_CONFIG_=280
+	,REJECT_SERVERS_=281
+	,PREFERRED_SERVERS_=282
+	,IA_=283
+	,TA_=284
+	,IAID_=285
+	,ADDRESS_=286
+	,NAME_=287
+	,IPV6ADDR_=288
+	,WORKDIR_=289
+	,RAPID_COMMIT_=290
+	,OPTION_=291
+	,SCRIPT_=292
+	,LOGNAME_=293
+	,LOGLEVEL_=294
+	,LOGMODE_=295
+	,LOGCOLORS_=296
+	,STRING_=297
+	,HEXNUMBER_=298
+	,INTNUMBER_=299
+	,DUID_=300
+	,STRICT_RFC_NO_ROUTING_=301
+	,SKIP_CONFIRM_=302
+	,PD_=303
+	,PREFIX_=304
+	,DUID_TYPE_=305
+	,DUID_TYPE_LLT_=306
+	,DUID_TYPE_LL_=307
+	,DUID_TYPE_EN_=308
+	,AUTH_ENABLED_=309
+	,AUTH_ACCEPT_METHODS_=310
+	,DIGEST_NONE_=311
+	,DIGEST_PLAIN_=312
+	,DIGEST_HMAC_MD5_=313
+	,DIGEST_HMAC_SHA1_=314
+	,DIGEST_HMAC_SHA224_=315
+	,DIGEST_HMAC_SHA256_=316
+	,DIGEST_HMAC_SHA384_=317
+	,DIGEST_HMAC_SHA512_=318
+	,STATELESS_=319
+	,ANON_INF_REQUEST_=320
+	,INSIST_MODE_=321
+	,INACTIVE_MODE_=322
+	,EXPERIMENTAL_=323
+	,ADDR_PARAMS_=324
+	,REMOTE_AUTOCONF_=325
+	,AFTR_=326
+	,ROUTING_=327
+	,ADDRESS_LIST_=328
+	,STRING_KEYWORD_=329
+	,REQUEST_=330
+	,RECONFIGURE_=331
 
 
 #line 215 "../bison++/bison.h"
