@@ -7,27 +7,23 @@
  *
  * released under GNU GPL v2 only licence
  *
- * $Id: ClntMsgConfirm.cpp,v 1.13 2008-11-11 22:19:54 thomson Exp $
+ * $Id: ClntMsgConfirm.cpp,v 1.14 2009-03-24 23:17:17 thomson Exp $
  *
  */
 
 #include "SmartPtr.h"
 #include "ClntMsgConfirm.h"
-#include "ClntOptClientIdentifier.h"
+#include "OptDUID.h"
 #include "ClntOptStatusCode.h"
 #include "ClntOptIA_NA.h"
 #include "DHCPConst.h"
 #include "Logger.h"
 
 //  iaLst - contain all IA's to  be checked (they have to be in the same link)
-TClntMsgConfirm::TClntMsgConfirm(SmartPtr<TClntIfaceMgr> IfaceMgr, 
-				 SmartPtr<TClntTransMgr> TransMgr, 
-				 SmartPtr<TClntCfgMgr>	CfgMgr, 
-				 SmartPtr<TClntAddrMgr> AddrMgr,
-				 unsigned int iface, 
-				 TContainer<SmartPtr<TAddrIA> > iaLst)
-    :TClntMsg(IfaceMgr,TransMgr,CfgMgr, AddrMgr, iface, SmartPtr<TIPv6Addr>() /*NULL*/,CONFIRM_MSG) {   
-
+TClntMsgConfirm::TClntMsgConfirm(unsigned int iface, 
+                                 List(TAddrIA) iaLst)
+  :TClntMsg(iface, 0, CONFIRM_MSG) {   
+  
     IRT = CNF_TIMEOUT;
     MRT = CNF_MAX_RT;
     MRC = 0;
@@ -39,7 +35,7 @@ TClntMsgConfirm::TClntMsgConfirm(SmartPtr<TClntIfaceMgr> IfaceMgr,
 
     //The client MUST include a Client Identifier option to identify itself
     //to the server.  
-    Options.append(new TClntOptClientIdentifier( CfgMgr->getDUID(), this ) );
+    Options.push_back(new TOptDUID(OPTION_CLIENTID, ClntCfgMgr().getDUID(), this ) );
     //The client includes IA options for all of the IAs
     //assigned to the interface for which the Confirm message is being
     //sent.  The IA options include all of the addresses the client
@@ -47,22 +43,22 @@ TClntMsgConfirm::TClntMsgConfirm(SmartPtr<TClntIfaceMgr> IfaceMgr,
     //T1 and T2 fields in any IA_NA options, and the preferred-lifetime and
     //valid-lifetime fields in the IA Address options to 0, as the server
     //will ignore these fields. 
-    SmartPtr<TAddrIA> ia;
+    SPtr<TAddrIA> ia;
     iaLst.first();
     while(ia=iaLst.get())
-        Options.append(new TClntOptIA_NA(ia,true,this));
+        Options.push_back(new TClntOptIA_NA(ia,true,this));
 
     appendRequestedOptions();
-    appendAuthenticationOption(AddrMgr);
+    appendElapsedOption();
+    appendAuthenticationOption();
     
-    this->IsDone = false;
-    pkt = new char[getSize()];
-    this->send();
+    IsDone = false;
+    send();
 }           
-
-void TClntMsgConfirm::answer(SmartPtr<TClntMsg> reply)
+    
+void TClntMsgConfirm::answer(SPtr<TClntMsg> reply)
 {
-    SmartPtr <TClntOptStatusCode> ptrOptCode;
+    SPtr <TClntOptStatusCode> ptrOptCode;
     ptrOptCode = (Ptr*) reply->getOption(OPTION_STATUS_CODE);
     switch (ptrOptCode->getCode() ) {
     case STATUSCODE_SUCCESS:
@@ -87,15 +83,16 @@ void TClntMsgConfirm::answer(SmartPtr<TClntMsg> reply)
 }
 
 void TClntMsgConfirm::addrsAccepted() {
-    SmartPtr<TAddrIA> ptrIA;
-    SmartPtr<TOpt> ptrOpt;
+    SPtr<TAddrIA> ptrIA;
+    SPtr<TOpt> ptrOpt;
     this->firstOption();
+    SPtr<TAddrAddr> ptrAddrAddr;
     while ( ptrOpt = this->getOption() ) {
 	if (ptrOpt->getOptType()!=OPTION_IA_NA)
 	    continue;
 
-	SmartPtr<TClntOptIA_NA> ptrOptIA = (Ptr*) ptrOpt;
-	ptrIA = ClntAddrMgr->getIA( ptrOptIA->getIAID() );
+	SPtr<TClntOptIA_NA> ptrOptIA = (Ptr*) ptrOpt;
+	ptrIA = ClntAddrMgr().getIA( ptrOptIA->getIAID() );
 	if (!ptrIA)
 	    continue;
 
@@ -106,32 +103,37 @@ void TClntMsgConfirm::addrsAccepted() {
 	// ptrIA->setTimestamp( now()-ptrIA->getT1() );
 	ptrIA->setState(STATE_CONFIGURED);
     }
-    ClntAddrMgr->firstIA();
+    ClntAddrMgr().firstIA();
+	SPtr<TIfaceIface> ptrIface;
+	ptrIface = ClntIfaceMgr().getIfaceByID(ptrIA->getIface());
+	ptrIA->firstAddr();
+	ptrAddrAddr = ptrIA->getAddr();
+	ptrIface->addAddr(ptrAddrAddr->get(),ptrAddrAddr->getPref(),ptrAddrAddr->getValid(),ptrIface->getPrefixLength());
 }
 
 void TClntMsgConfirm::addrsRejected() {
-    SmartPtr<TAddrIA> ptrIA;
-    SmartPtr<TOpt> ptrOpt;
+    SPtr<TAddrIA> ptrIA;
+    SPtr<TOpt> ptrOpt;
     this->firstOption();
     while ( ptrOpt = this->getOption() ) {
 	if (ptrOpt->getOptType()!=OPTION_IA_NA)
 	    continue;
 
-	SmartPtr<TClntOptIA_NA> ptrOptIA = (Ptr*) ptrOpt;
-	ptrIA = ClntAddrMgr->getIA(ptrOptIA->getIAID());
+	SPtr<TClntOptIA_NA> ptrOptIA = (Ptr*) ptrOpt;
+	ptrIA = ClntAddrMgr().getIA(ptrOptIA->getIAID());
 	if (!ptrIA)
 	    continue;
 
 	// release all addrs
-	SmartPtr<TIfaceIface> ptrIface;
-	ptrIface = ClntIfaceMgr->getIfaceByID(ptrIA->getIface());
+	SPtr<TIfaceIface> ptrIface;
+	ptrIface = ClntIfaceMgr().getIfaceByID(ptrIA->getIface());
 	if (!ptrIface) {
 	    Log(Crit) << "We have addresses assigned to non-existing interface."
 		"Help! Somebody stole an interface!" << LogEnd;
 	    ptrIA->setState(STATE_NOTCONFIGURED);
 	    return;
 	}
-	SmartPtr<TAddrAddr> ptrAddr;
+	SPtr<TAddrAddr> ptrAddr;
 	ptrIA->firstAddr();
 	while (ptrAddr = ptrIA->getAddr() ) {
 	    // remove addr from ...
@@ -140,12 +142,12 @@ void TClntMsgConfirm::addrsRejected() {
 	    ptrIA->delAddr( ptrAddr->get() );
 	}
 
-        //not only the address should be rejected, but also the original IA should be deleted and using a new IA to process SOLICIT
-	ptrIA->setState(STATE_NOTCONFIGURED);
-	SmartPtr<TClntCfgIA> ptrCfgIA = ClntCfgMgr->getIA(ptrOptIA->getIAID());
-	ptrCfgIA->setState(STATE_NOTCONFIGURED);
+	//not only the address should be rejected, but also the original IA should be deleted and using a new IA to process SOLICIT
+	SPtr<TClntCfgIA> ptrCfgIA = ClntCfgMgr().getIA(ptrOptIA->getIAID());
+	ptrCfgIA->reset();
+	ptrIA->reset();
     }
-    ClntAddrMgr->firstIA();
+    ClntAddrMgr().firstIA();
 }
 
 void TClntMsgConfirm::doDuties()
@@ -153,7 +155,7 @@ void TClntMsgConfirm::doDuties()
     
     //The first Confirm message from the client on the interface MUST be
     //delayed by a random amount of time between 0 and CNF_MAX_DELAY.    
-    // FIXME:
+    /// @todo:
         //if (RC == 0) ;
 		//microsleep(rand()%1000000);
     if (!MRD) {
@@ -181,7 +183,5 @@ string TClntMsgConfirm::getName() {
     return "CONFIRM";
 }
 
-TClntMsgConfirm::~TClntMsgConfirm()
-{
-    delete [] pkt;
+TClntMsgConfirm::~TClntMsgConfirm() {
 }
