@@ -7,7 +7,7 @@
  *
  * released under GNU GPL v2 only licence
  *
- * $Id: ClntMsgInfRequest.cpp,v 1.15 2008-08-29 00:07:28 thomson Exp $
+ * $Id: ClntMsgInfRequest.cpp,v 1.16 2009-03-24 23:17:17 thomson Exp $
  *
  */
 
@@ -17,8 +17,7 @@
 #include "Container.h"
 #include "ClntIfaceMgr.h"
 #include "ClntMsgAdvertise.h"
-#include "ClntOptServerIdentifier.h"
-#include "ClntOptClientIdentifier.h"
+#include "OptDUID.h"
 #include "ClntOptIA_NA.h"
 #include "ClntOptElapsed.h"
 #include "Logger.h"
@@ -30,13 +29,8 @@
 #include "ClntOptTimeZone.h"
 #include <cmath>
 
-TClntMsgInfRequest::TClntMsgInfRequest(SmartPtr<TClntIfaceMgr> IfaceMgr, 
-				       SmartPtr<TClntTransMgr> TransMgr,
-				       SmartPtr<TClntCfgMgr>   CfgMgr, 
-				       SmartPtr<TClntAddrMgr>  AddrMgr, 
-				       SmartPtr<TClntCfgIface> iface)
-    :TClntMsg(IfaceMgr, TransMgr, CfgMgr, AddrMgr, iface->getID(), SmartPtr<TIPv6Addr>() /*NULL*/, 
-	      INFORMATION_REQUEST_MSG) {
+TClntMsgInfRequest::TClntMsgInfRequest(SPtr<TClntCfgIface> iface)
+    :TClntMsg(iface->getID(), 0, INFORMATION_REQUEST_MSG) {
 
     IRT = INF_TIMEOUT;
     MRT = INF_MAX_RT;
@@ -47,28 +41,23 @@ TClntMsgInfRequest::TClntMsgInfRequest(SmartPtr<TClntIfaceMgr> IfaceMgr,
     Iface=iface->getID();
     IsDone=false;
 
-    if (!CfgMgr->anonInfRequest()) {
-	Options.append(new TClntOptClientIdentifier(ClntCfgMgr->getDUID(),this));
+    if (!ClntCfgMgr().anonInfRequest()) {
+        Options.push_back(new TOptDUID(OPTION_CLIENTID, ClntCfgMgr().getDUID(), this));
     } else {
-	Log(Info) << "Sending anonymous INF-REQUEST (ClientID not included)." << LogEnd;
+        Log(Info) << "Sending anonymous INF-REQUEST (ClientID not included)." << LogEnd;
     }
 
     this->appendRequestedOptions();
 
-    appendAuthenticationOption(AddrMgr);
-
-    pkt = new char[getSize()];
+    appendAuthenticationOption();
+    appendElapsedOption();
+    send();
 }
 
 //opts - all options list WITHOUT serverDUID including server id
-TClntMsgInfRequest::TClntMsgInfRequest(SmartPtr<TClntIfaceMgr> IfaceMgr, 
-				       SmartPtr<TClntTransMgr> TransMgr,
-				       SmartPtr<TClntCfgMgr>   CfgMgr, 
-				       SmartPtr<TClntAddrMgr> AddrMgr, 
-				       TContainer< SmartPtr<TOpt> > ReqOpts,
+TClntMsgInfRequest::TClntMsgInfRequest(TOptList ReqOpts,
 				       int iface)
-    :TClntMsg(IfaceMgr,TransMgr,CfgMgr,AddrMgr,iface,SmartPtr<TIPv6Addr>() /*NULL*/,
-	      INFORMATION_REQUEST_MSG) {
+    :TClntMsg(iface, 0, INFORMATION_REQUEST_MSG) {
     IRT = INF_TIMEOUT;
     MRT = INF_MAX_RT;
     MRC = 0;
@@ -78,22 +67,22 @@ TClntMsgInfRequest::TClntMsgInfRequest(SmartPtr<TClntIfaceMgr> IfaceMgr,
     Iface=iface;
     IsDone=false;
     
-    SmartPtr<TIfaceIface> ptrIface = IfaceMgr->getIfaceByID(iface);
+    SPtr<TIfaceIface> ptrIface = ClntIfaceMgr().getIfaceByID(iface);
     if (!ptrIface) {
-	Log(Error) << "Unable to find interface with ifindex=" << iface 
-		   << " while trying to generate INF-REQUEST." << LogEnd;
-	this->IsDone = true;
-	return;
+        Log(Error) << "Unable to find interface with ifindex=" << iface 
+                   << " while trying to generate INF-REQUEST." << LogEnd;
+        IsDone = true;
+        return;
     }
-    Log(Debug) << "Creating INF-REQUEST on the " << ptrIface->getName()
-	       << "/" << iface << "." << LogEnd;
+    Log(Debug) << "Creating INF-REQUEST on the " << ptrIface->getFullName()
+	           << "." << LogEnd;
     
     // copy whole list from Verify ...
     Options = ReqOpts;
     
-    SmartPtr<TOpt> opt;
-    Options.first();
-    while(opt=Options.get())
+    SPtr<TOpt> opt;
+    firstOption();
+    while(opt=getOption())
     {
         switch (opt->getOptType())
         {       
@@ -113,7 +102,8 @@ TClntMsgInfRequest::TClntMsgInfRequest(SmartPtr<TClntIfaceMgr> IfaceMgr,
             case OPTION_AUTH:
             case OPTION_AAAAUTH:
             case OPTION_KEYGEN:
-                Options.del();
+	    case OPTION_ELAPSED_TIME:       //delete the old elapsed option,as we will append a new one
+                delOption(opt->getOptType());
                 break;        
         }
         //The other options can be included in Information request option
@@ -122,23 +112,20 @@ TClntMsgInfRequest::TClntMsgInfRequest(SmartPtr<TClntIfaceMgr> IfaceMgr,
         //RECONF_ACCEPT - maybe also SERVERID if information request
         //is answer to reconfigure message
     }
+    appendElapsedOption();
+    appendAuthenticationOption();
 
-    appendAuthenticationOption(AddrMgr);
-
-    pkt = new char[getSize()];
+    this->send();
 }
 
 
-void TClntMsgInfRequest::answer(SmartPtr<TClntMsg> msg)
+void TClntMsgInfRequest::answer(SPtr<TClntMsg> msg)
 {
-    //server DUID from which there is answer
-    SmartPtr<TClntOptServerIdentifier> ptrDUID;
-    ptrDUID = (Ptr*) msg->getOption(OPTION_SERVERID);
     //which option have we requested from server
-    SmartPtr<TClntOptOptionRequest> ptrORO;
+    SPtr<TClntOptOptionRequest> ptrORO;
     ptrORO = (Ptr*)getOption(OPTION_ORO);
     
-    SmartPtr<TOpt> option;
+    SPtr<TOpt> option;
     msg->firstOption();
     while(option = msg->getOption())
     {
@@ -149,38 +136,40 @@ void TClntMsgInfRequest::answer(SmartPtr<TClntMsg> msg)
 	}
 	if ( ptrORO && (ptrORO->isOption(option->getOptType())) )
 	    ptrORO->delOption(option->getOptType());
-	SmartPtr<TOpt> requestOpt;
+	SPtr<TOpt> requestOpt;
 	this->firstOption();
 	while ( requestOpt = this->getOption()) 
 	{
-	    if (requestOpt->getOptType()==option->getOptType())
-		this->Options.del();
+	    if (requestOpt->getOptType()==option->getOptType()) {
+		delOption(requestOpt->getOptType());
+		break;
+	    }
 	}//while
     }
-
+    
     ptrORO->delOption(OPTION_INFORMATION_REFRESH_TIME);
     if (ptrORO && ptrORO->count())
     {
-	if (ClntCfgMgr->insistMode()){ 
+	if (ClntCfgMgr().insistMode()){ 
 	    Log(Notice) << "Insist-mode enabled. Not all options were assigned (";
 	    for (int i=0; i<ptrORO->count(); i++)
-		Log(Cont) << ptrORO->getReqOpt(i) << " ";
+                Log(Cont) << ptrORO->getReqOpt(i) << " ";
 	    Log(Cont) << "). Sending new INFORMATION-REQUEST." << LogEnd;
-	    ClntTransMgr->sendInfRequest(Options,Iface);
+	    ClntTransMgr().sendInfRequest(Options,Iface);
 	} else {
 	    Log(Notice) << "Insist-mode disabled. Not all options were assigned (";
 	    for (int i=0; i<ptrORO->count(); i++)
-		Log(Cont) << ptrORO->getReqOpt(i) << " ";
+                Log(Cont) << ptrORO->getReqOpt(i) << " ";
 	    Log(Cont) << "). They will remain unconfigured." << LogEnd;
 	    IsDone = true;
 	}
     } else {
-	Log(Debug) << "All requested options were assigned." << LogEnd;
+        Log(Debug) << "All requested options were assigned." << LogEnd;
         IsDone=true;
     }
     return;
 }
-
+    
 void TClntMsgInfRequest::doDuties()
 {
     //timeout is reached, so let's retrasmit this message
@@ -197,8 +186,5 @@ string TClntMsgInfRequest::getName() {
     return "INF-REQUEST";
 }
 
-TClntMsgInfRequest::~TClntMsgInfRequest()
-{
-    delete [] pkt;
-    pkt=NULL;
+TClntMsgInfRequest::~TClntMsgInfRequest() {
 }
