@@ -8,10 +8,7 @@
  *
  * $Id: ClntOptDomainName.h,v 1.4 2008-08-29 00:07:28 thomson Exp $
  *
- * $Log: ClntOptDomainName.h,v $
- * Revision 1.4  2008-08-29 00:07:28  thomson
- * Temporary license change(GPLv2 or later -> GPLv2 only)
- *
+ * $Log: not supported by cvs2svn $
  * Revision 1.3  2004-10-25 20:45:53  thomson
  * Option support, parsers rewritten. ClntIfaceMgr now handles options.
  *
@@ -32,8 +29,8 @@ class TClntOptDomainName : public TOptStringLst
     TClntOptDomainName(List(string) * domains, TMsg* parent);
     TClntOptDomainName(char *buf, int bufsize, TMsg* parent);
     bool doDuties();
-    void setSrvDuid(SmartPtr<TDUID> duid);
+    void setSrvDuid(SPtr<TDUID> duid);
 private:
-    SmartPtr<TDUID> SrvDUID;
+    SPtr<TDUID> SrvDUID;
 };
 #endif
