@@ -11,7 +11,6 @@
  */
 
 #include "ClntOptNISDomain.h"
-#include "ClntOptServerIdentifier.h"
 #include "Portable.h"
 #include "ClntMsg.h"
 #include "Logger.h"
@@ -27,32 +26,26 @@ TClntOptNISDomain::TClntOptNISDomain(char *buf, int bufsize, TMsg* parent)
 bool TClntOptNISDomain::doDuties() {
     string reason = "trying to set NIS domain.";
     int ifindex = this->Parent->getIface();
-    SmartPtr<TIPv6Addr> addr = this->Parent->getAddr();
-    TClntMsg * msg = (TClntMsg*)(this->Parent);
-    SmartPtr<TClntIfaceMgr> ifaceMgr = msg->getClntIfaceMgr();
-    if (!ifaceMgr) {
-	Log(Error) << "Unable to access IfaceMgr while " << reason << LogEnd;
+
+    if (!DUID) {
+        Log(Error) << "Unable to find proper DUID while " << reason << LogEnd;
         return false;
     }
-    SmartPtr<TClntIfaceIface> iface = (Ptr*)ifaceMgr->getIfaceByID(ifindex);
+
+    SPtr<TClntIfaceIface> iface = (Ptr*)ClntIfaceMgr().getIfaceByID(ifindex);
     if (!iface) {
-	Log(Error) << "Unable to find interface with ifindex=" << ifindex 
-		   << " while " << reason << LogEnd;
+        Log(Error) << "Unable to find interface ifindex=" << ifindex
+            << reason << LogEnd;
         return false;
     }
 
-    if (!this->DUID) {
-	Log(Error) << "Unable to find proper DUID while " << reason << LogEnd;
-	return false;
-    }
-
-    SmartPtr<TClntCfgMgr> cfgMgr = msg->getClntCfgMgr();
-    SmartPtr<TClntCfgIface> cfgIface = cfgMgr->getIface(ifindex);
+    SPtr<TClntCfgIface> cfgIface = ClntCfgMgr().getIface(ifindex);
     cfgIface->setNISDomainState(STATE_CONFIGURED);
 
-    return iface->setNISDomain(this->DUID, addr,this->Str);
+    return iface->setNISDomain(DUID, Parent->getAddr(), Str);
 }
 
-void TClntOptNISDomain::setSrvDuid(SmartPtr<TDUID> duid) {
+/// @todo remove
+void TClntOptNISDomain::setSrvDuid(SPtr<TDUID> duid) {
     this->SrvDUID=duid;
 }
