@@ -8,10 +8,7 @@
  *
  * $Id: ClntOptNISPDomain.h,v 1.2 2008-08-29 00:07:29 thomson Exp $
  *
- * $Log: ClntOptNISPDomain.h,v $
- * Revision 1.2  2008-08-29 00:07:29  thomson
- * Temporary license change(GPLv2 or later -> GPLv2 only)
- *
+ * $Log: not supported by cvs2svn $
  * Revision 1.1  2004-10-25 20:45:53  thomson
  * Option support, parsers rewritten. ClntIfaceMgr now handles options.
  *
@@ -31,8 +28,8 @@ class TClntOptNISPDomain : public TOptString
     TClntOptNISPDomain(string domain, TMsg* parent);
     TClntOptNISPDomain(char *buf, int bufsize, TMsg* parent);
     bool doDuties();
-    void setSrvDuid(SmartPtr<TDUID> duid);
+    void setSrvDuid(SPtr<TDUID> duid);
 private:
-    SmartPtr<TDUID> SrvDUID;
+    SPtr<TDUID> SrvDUID;
 };
 #endif
