@@ -8,10 +8,7 @@
  *
  * $Id: ClntOptNISPServer.h,v 1.2 2008-08-29 00:07:29 thomson Exp $
  *
- * $Log: ClntOptNISPServer.h,v $
- * Revision 1.2  2008-08-29 00:07:29  thomson
- * Temporary license change(GPLv2 or later -> GPLv2 only)
- *
+ * $Log: not supported by cvs2svn $
  * Revision 1.1  2004-10-25 20:45:53  thomson
  * Option support, parsers rewritten. ClntIfaceMgr now handles options.
  *
@@ -29,8 +26,8 @@ class TClntOptNISPServers : public TOptAddrLst
     TClntOptNISPServers(List(TIPv6Addr) * lst, TMsg* parent);
     TClntOptNISPServers(char* buf, int size, TMsg* parent);
     bool doDuties();
-    void setSrvDuid(SmartPtr<TDUID> duid);
+    void setSrvDuid(SPtr<TDUID> duid);
  private:
-    SmartPtr<TDUID> SrvDUID;
+    SPtr<TDUID> SrvDUID;
 };
 #endif
