@@ -8,10 +8,7 @@
  *
  * $Id: ClntOptOptionRequest.h,v 1.4 2008-08-29 00:07:29 thomson Exp $
  *
- * $Log: ClntOptOptionRequest.h,v $
- * Revision 1.4  2008-08-29 00:07:29  thomson
- * Temporary license change(GPLv2 or later -> GPLv2 only)
- *
+ * $Log: not supported by cvs2svn $
  * Revision 1.3  2006-02-02 23:16:54  thomson
  * 0.4.2 release.
  *
@@ -33,11 +30,11 @@ class TClntConfMgr;
 class TClntOptOptionRequest : public TOptOptionRequest 
 {
  public:
-    TClntOptOptionRequest(SmartPtr<TClntCfgIface> ptrIface, TMsg* parent);
+    TClntOptOptionRequest(SPtr<TClntCfgIface> ptrIface, TMsg* parent);
     TClntOptOptionRequest( char * buf,  int n, TMsg* parent);
     bool doDuties();
  private:
-    SmartPtr<TClntCfgMgr> CfgMgr;
+    SPtr<TClntCfgMgr> CfgMgr;
 };
 
 #endif
