@@ -11,7 +11,6 @@
  */
 
 #include "ClntOptSIPDomain.h"
-#include "ClntOptServerIdentifier.h"
 #include "Portable.h"
 #include "ClntMsg.h"
 #include "Logger.h"
@@ -27,32 +26,26 @@ TClntOptSIPDomain::TClntOptSIPDomain(char *buf, int bufsize, TMsg* parent)
 bool TClntOptSIPDomain::doDuties() {
     string reason = "trying to set SIP domain(s).";
     int ifindex = this->Parent->getIface();
-    SmartPtr<TIPv6Addr> addr = this->Parent->getAddr();
-    TClntMsg * msg = (TClntMsg*)(this->Parent);
-    SmartPtr<TClntIfaceMgr> ifaceMgr = msg->getClntIfaceMgr();
-    if (!ifaceMgr) {
-	Log(Error) << "Unable to access IfaceMgr while " << reason << LogEnd;
-        return false;
-    }
-    SmartPtr<TClntIfaceIface> iface = (Ptr*)ifaceMgr->getIfaceByID(ifindex);
-    if (!iface) {
-	Log(Error) << "Unable to find interface with ifindex=" << ifindex 
-		   << " while " << reason << LogEnd;
-        return false;
-    }
 
     if (!this->DUID) {
-	Log(Error) << "Unable to find proper DUID while " << reason << LogEnd;
-	return false;
+        Log(Error) << "Unable to find proper DUID while " << reason << LogEnd;
+        return false;
     }
 
-    SmartPtr<TClntCfgMgr> cfgMgr = msg->getClntCfgMgr();
-    SmartPtr<TClntCfgIface> cfgIface = cfgMgr->getIface(ifindex);
+    SPtr<TClntIfaceIface> iface = (Ptr*)ClntIfaceMgr().getIfaceByID(ifindex);
+    if (!iface) {
+        Log(Error) << "Unable to find interface ifindex=" << ifindex
+            << reason << LogEnd;
+        return false;
+    }
+
+    SPtr<TClntCfgIface> cfgIface = ClntCfgMgr().getIface(ifindex);
     cfgIface->setSIPDomainState(STATE_CONFIGURED);
 
-    return iface->setSIPDomainLst(this->DUID, addr,this->StringLst);
+    return iface->setSIPDomainLst(DUID, Parent->getAddr(), StringLst);
 }
 
-void TClntOptSIPDomain::setSrvDuid(SmartPtr<TDUID> duid) {
+/// @todo remove
+void TClntOptSIPDomain::setSrvDuid(SPtr<TDUID> duid) {
     this->SrvDUID=duid;
 }
