@@ -10,7 +10,6 @@
  */
 
 #include "ClntOptSIPServer.h"
-#include "ClntOptServerIdentifier.h"
 #include "ClntMsg.h"
 #include "Logger.h"
 
@@ -24,34 +23,28 @@ TClntOptSIPServers::TClntOptSIPServers(char* buf, int size, TMsg* parent)
 
 bool TClntOptSIPServers::doDuties() {
     string reason = "trying to set SIP server(s).";
-    int ifindex = this->Parent->getIface();
-    SmartPtr<TIPv6Addr> addr = this->Parent->getAddr();
-    TClntMsg * msg = (TClntMsg*)(this->Parent);
-    SmartPtr<TClntIfaceMgr> ifaceMgr = msg->getClntIfaceMgr();
-    if (!ifaceMgr) {
-	Log(Error) << "Unable to access IfaceMgr while " << reason << LogEnd;
-        return false;
-    }
-    SmartPtr<TClntIfaceIface> iface = (Ptr*)ifaceMgr->getIfaceByID(ifindex);
-    if (!iface) {
-	Log(Error) << "Unable to find interface with ifindex=" << ifindex 
-		   << " while " << reason << LogEnd;
-        return false;
-    }
+    int ifindex = Parent->getIface();
 
     if (!this->DUID) {
-	Log(Error) << "Unable to find proper DUID while " << reason << LogEnd;
-	return false;
+        Log(Error) << "Unable to find proper DUID while " << reason << LogEnd;
+        return false;
     }
 
-    SmartPtr<TClntCfgMgr> cfgMgr = msg->getClntCfgMgr();
-    SmartPtr<TClntCfgIface> cfgIface = cfgMgr->getIface(ifindex);
+    SPtr<TClntIfaceIface> iface = (Ptr*)ClntIfaceMgr().getIfaceByID(ifindex);
+    if (!iface) {
+        Log(Error) << "Unable to find interface ifindex=" << ifindex
+            << reason << LogEnd;
+        return false;
+    }
+
+    SPtr<TClntCfgIface> cfgIface = ClntCfgMgr().getIface(ifindex);
     cfgIface->setSIPServerState(STATE_CONFIGURED);
 
-    return iface->setSIPServerLst(this->DUID, addr,this->AddrLst);
+    return iface->setSIPServerLst(DUID, Parent->getAddr(), AddrLst);
 }
 
-void TClntOptSIPServers::setSrvDuid(SmartPtr<TDUID> duid)
+/// @todo remove
+void TClntOptSIPServers::setSrvDuid(SPtr<TDUID> duid)
 {
     this->SrvDUID=duid;
 }
