@@ -6,8 +6,6 @@
  *
  * released under GNU GPL v2 only licence
  *
- * $Id: IfaceMgr.h,v 1.9 2008-08-29 00:07:30 thomson Exp $
- *
  */
 
 class TIfaceMgr;
@@ -16,9 +14,12 @@ class TIfaceMgr;
 
 #include "SmartPtr.h"
 #include "Container.h"
+#include "ScriptParams.h"
 
 #include "Iface.h"
 
+class TMsg;
+class TOpt;
 
 class TIfaceMgr {
   public:
@@ -28,25 +29,30 @@ class TIfaceMgr {
 
     // ---Iface related---
     void firstIface();
-    SmartPtr<TIfaceIface> getIface();
-    SmartPtr<TIfaceIface> getIfaceByName(string name);
-    SmartPtr<TIfaceIface> getIfaceByID(int id);
-    SmartPtr<TIfaceIface> getIfaceBySocket(int fd);
+    SPtr<TIfaceIface> getIface();
+    SPtr<TIfaceIface> getIfaceByName(string name);
+    SPtr<TIfaceIface> getIfaceByID(int id);
+    SPtr<TIfaceIface> getIfaceBySocket(int fd);
     int countIface();
 
     // ---other---
-    int select(unsigned long time, char *buf, int &bufsize, SmartPtr<TIPv6Addr> peer);
+    int select(unsigned long time, char *buf, int &bufsize, SPtr<TIPv6Addr> peer);
     string printMac(char * mac, int macLen);
     void dump();
     bool isDone();
 
-    ~TIfaceMgr();
+    void notifyScripts(std::string scriptName, SPtr<TMsg> question, SPtr<TMsg> answer);
+    void notifyScripts(std::string scriptName, SPtr<TMsg> question, SPtr<TMsg> answer,
+                       TNotifyScriptParams& params);
+    void notifyScript(std::string scriptName, std::string action, TNotifyScriptParams& params);
+
+    virtual ~TIfaceMgr();
 
  protected:
+    virtual void optionToEnv(TNotifyScriptParams& params, SPtr<TOpt> opt, std::string txtPrefix );
+
     string XmlFile;
-
     List(TIfaceIface) IfaceLst; //Interface list
-
     bool IsDone; 
 };
 
