@@ -10,20 +10,19 @@
 
 #include <stdlib.h>
 #include <cmath>
-#ifdef WIN32
-#include <winsock2.h>
-#endif
 #include "Portable.h"
 #include "DHCPConst.h"
 #include "SmartPtr.h"
 #include "Container.h"
-
 #include "Msg.h"
 #include "Opt.h"
 #include "Logger.h"
 #include "hmac.h"
 
-TMsg::TMsg(int iface, SmartPtr<TIPv6Addr> addr, char* &buf, int &bufSize)
+class TNotifyScriptParams;
+
+TMsg::TMsg(int iface, SPtr<TIPv6Addr> addr, char* &buf, int &bufSize)
+    :pkt(0), NotifyScripts(NULL)
 {
     setAttribs(iface, addr, 0, 0);
     if (bufSize<4)
@@ -32,22 +31,22 @@ TMsg::TMsg(int iface, SmartPtr<TIPv6Addr> addr, char* &buf, int &bufSize)
     unsigned char * buf2 = (unsigned char *)(buf+1);
     this->TransID= ((long)buf2[0])<<16 | ((long)buf2[1])<<8 | (long)buf2[2];
     buf+=4; bufSize-=4;
-    this->pkt = 0;
 }
 
-TMsg::TMsg(int iface, SmartPtr<TIPv6Addr> addr, int msgType)
+TMsg::TMsg(int iface, SPtr<TIPv6Addr> addr, int msgType)
+    :pkt(0), NotifyScripts(NULL)
 {
     long tmp = rand() % (255*255*255);
     setAttribs(iface,addr,msgType,tmp);
-    this->pkt = 0;
 }
 
-TMsg::TMsg(int iface, SmartPtr<TIPv6Addr> addr, int msgType,  long transID)
+TMsg::TMsg(int iface, SPtr<TIPv6Addr> addr, int msgType,  long transID)
+    :NotifyScripts(NULL)
 {
     setAttribs(iface,addr,msgType,transID);
 }
 
-void TMsg::setAttribs(int iface, SmartPtr<TIPv6Addr> addr, int msgType, long transID)
+void TMsg::setAttribs(int iface, SPtr<TIPv6Addr> addr, int msgType, long transID)
 {
     PeerAddr=addr;
 
@@ -68,12 +67,13 @@ void TMsg::setAttribs(int iface, SmartPtr<TIPv6Addr> addr, int msgType, long tra
 
 int TMsg::getSize()
 {
-    SmartPtr<TOpt> Option;
     int pktsize=0;
-    Options.first();
-    while( Option = Options.get() )
-	pktsize+=Option->getSize();
-    return pktsize+4;
+    TOptList::iterator opt;
+    for (opt = Options.begin(); opt!=Options.end(); ++opt)
+    {
+	pktsize += (*opt)->getSize();
+    }
+    return pktsize + 4;
 }
 
 unsigned long TMsg::getTimeout()
@@ -91,7 +91,7 @@ long TMsg::getTransID()
     return TransID;
 }
 
-TContainer< SmartPtr<TOpt> > TMsg::getOptLst()
+TOptList & TMsg::getOptLst()
 {
     return Options;
 }
@@ -112,12 +112,11 @@ int TMsg::storeSelf(char * buffer)
     buffer[1] = tmp%256;  tmp = tmp/256;
     buffer[0] = tmp%256;  tmp = tmp/256;
     buffer+=3;
-    Options.first();
-    SmartPtr<TOpt> Option;
-    while( Option = Options.get() )
-    {
-        Option->storeSelf(buffer);
-        buffer += Option->getSize();
+
+    TOptList::iterator option;
+    for (option=Options.begin(); option!=Options.end(); ++option) {
+        (*option)->storeSelf(buffer);
+	buffer += (*option)->getSize();
     }
 
 #ifndef MOD_DISABLE_AUTH
@@ -161,33 +160,38 @@ int TMsg::storeSelf(char * buffer)
     return buffer-start;
 }
 
-SmartPtr<TOpt> TMsg::getOption(int type) {
-    SmartPtr<TOpt> Option;
-    
-    Options.first();
-    while ( Option = Options.get() ) {
-	if (Option->getOptType()==type) 
-	    return Option;
-    }
-    return SmartPtr<TOpt>();
+SPtr<TOpt> TMsg::getOption(int type) {
+    TOptList::iterator opt;
+    for (opt = Options.begin(); opt!=Options.end(); ++opt)
+        if ( (*opt)->getOptType()==type) 
+	    return *opt;
+    return 0;
 }
 
 void TMsg::firstOption() {
-    Options.first();
+    NextOpt = Options.begin();
 }
 
 int TMsg::countOption() {
-    return Options.count();
+    return Options.size();
 }
 
-SmartPtr<TOpt> TMsg::getOption() {
-    return Options.get();
+SPtr<TOpt> TMsg::getOption() {
+    if (NextOpt != Options.end()) {
+	TOptList::iterator it = NextOpt;
+	++NextOpt;
+	return (*it);
+    }
+    return 0;
 }
 
 TMsg::~TMsg() {
+    if (NotifyScripts) {
+        delete NotifyScripts;
+    }
 }
 
-SmartPtr<TIPv6Addr> TMsg::getAddr() {
+SPtr<TIPv6Addr> TMsg::getAddr() {
     return PeerAddr;
 }
 
@@ -199,6 +203,11 @@ bool TMsg::isDone() {
     return IsDone;
 }
 
+bool TMsg::isDone(bool done) {
+    IsDone = done;
+    return IsDone;
+}
+
 void TMsg::setAuthInfoPtr(char* ptr) {
     AuthInfoPtr = ptr;
 }
@@ -225,7 +234,7 @@ int TMsg::setAuthInfoKey() {
     if (!KeyGenNonce)
         KeyGenNonceLen = 16;
 
-    // FIXME set proper size of Client ID (DUID?) (here and in hmac_sha())
+    /// @todo set proper size of Client ID (DUID?) (here and in hmac_sha())
     KeyGenNonce_ClientID = new char[KeyGenNonceLen+128];
 
     AAAkey = getAAAKey(AAASPI, &AAAkeyLen);
@@ -246,7 +255,7 @@ int TMsg::setAuthInfoKey() {
     if (KeyGenNonce)
         memcpy(KeyGenNonce_ClientID, KeyGenNonce, KeyGenNonceLen);
 
-    // FIXME fill also with ClientID (DUID?)
+    /// @todo fill also with ClientID (DUID?)
 
     PrintHex("Auth: Infokey: using KeyGenNonce+CliendID: ", KeyGenNonce_ClientID, KeyGenNonceLen+128);
 
@@ -317,7 +326,7 @@ bool TMsg::validateAuthInfo(char *buf, int bufSize) {
 
 bool TMsg::validateAuthInfo(char *buf, int bufSize, List(DigestTypes) authLst) {
     bool is_ok = false;
-    SmartPtr<DigestTypes> dt;
+    SPtr<DigestTypes> dt;
     bool dt_in_list = false;
     
     //empty list means that any digest type is accepted
@@ -408,16 +417,15 @@ bool TMsg::validateAuthInfo(char *buf, int bufSize, List(DigestTypes) authLst) {
  */
 bool TMsg::check(bool clntIDmandatory, bool srvIDmandatory)
 {
-    SmartPtr<TOpt> option;
+    SPtr<TOpt> option;
     int clntCnt=0;
     int srvCnt =0;
     int authCnt = 0;
     bool status = true;
 
-    Options.first();
-    while (option = Options.get() ) 
+    for (TOptList::iterator opt=Options.begin(); opt!=Options.end(); ++opt)
     {
-	switch (option->getOptType()) {
+	switch ( (*opt)->getOptType() ) {
 	case OPTION_CLIENTID:
 	    clntCnt++;
 	    break;
@@ -448,15 +456,32 @@ bool TMsg::check(bool clntIDmandatory, bool srvIDmandatory)
     if (!srvIDmandatory && (srvCnt)) {
 	Log(Warning) << "No ServerID option is allowed in the " << this->getName()
 		     << " message, but " << srvCnt << " received.";
+	status = false;
     }
 
     if (authCnt > 1) {
 	Log(Warning) << "No more that one authentication option is allowed in the " << this->getName()
 		     << " message, but " << srvCnt << " received.";
+	status = false;
     }
 
-    if (!status)
+    if (!status) {
 	Log(Cont) << "Message dropped." << LogEnd;
+	IsDone = true;
+    }
 
     return status;
 }
+
+bool TMsg::delOption(int code)
+{
+    for (TOptList::iterator opt = Options.begin(); opt!=Options.end(); ++opt)
+    {
+	if ( (*opt)->getOptType() == code) {
+	    Options.erase(opt);
+	    firstOption();
+	    return true;
+	}
+    }
+    return false;
+}
