@@ -6,7 +6,7 @@
  *                                                                           
  * released under GNU GPL v2 only licence                                
  *                                                                           
- * $Id: DHCPClient.h,v 1.7 2008-10-12 14:07:31 thomson Exp $
+ * $Id: DHCPClient.h,v 1.8 2009-03-24 23:17:18 thomson Exp $
  *                                                                           
  */
 
@@ -18,35 +18,24 @@
 #include "SmartPtr.h"
 #include "Portable.h"
 
-using namespace std;
-
-class TClntIfaceMgr;
-class TClntAddrMgr;
-class TClntCfgMgr;
-class TClntTransMgr;
-
 class TDHCPClient
 {
   public:
-    TDHCPClient(string config);
+    TDHCPClient(const std::string config);
     void run();
     void stop();
     void resetLinkstate();
     bool isDone();
     bool checkPrivileges();
-    void setWorkdir(std::string workdir);
-    SmartPtr<TClntAddrMgr>  getAddrMgr();
-    SmartPtr<TClntCfgMgr> getCfgMgr();
+    void setWorkdir(const std::string workdir);
+#ifdef MOD_CLNT_CONFIRM
+    void requestLinkstateChange();
+#endif
     char* getCtrlIface();
     ~TDHCPClient();
 
   private:
     void initLinkStateChange();
-
-    SmartPtr<TClntIfaceMgr> IfaceMgr;
-    SmartPtr<TClntAddrMgr>  AddrMgr;
-    SmartPtr<TClntCfgMgr>   CfgMgr;
-    SmartPtr<TClntTransMgr> TransMgr;
     bool IsDone;
     volatile link_state_notify_t linkstates;
 };
