@@ -9,7 +9,7 @@
  *
  */
 
-#include "limits.h"
+#include "DHCPDefaults.h"
 
 #ifndef DHCPCONST_H
 #define DHCPCONST_H
@@ -139,7 +139,7 @@
 // RFC-ietf-dhc-paa-option-05.txt
 #define OPTION_PANA_AGENT       40
 
-// RFC4833: Timezone options for DHCP 
+// RFC4833: Timezone options for DHCP
 #define OPTION_NEW_POSIX_TIMEZONE 41
 #define OPTION_NEW_TZDB_TIMEZONE  42
 
@@ -153,6 +153,9 @@
 #define OPTION_LQ_RELAY_DATA    47
 #define OPTION_LQ_CLIENT_LINK   48
 
+// draft-ietf-softwire-ds-lite-tunnel-option-10, approved by IESG
+#define OPTION_AFTR_NAME        64
+
 // The following option numbers are not yet standardized and
 // won't interoperate with other implementations
 // option formats taken from:
@@ -160,79 +163,44 @@
 #define OPTION_AAAAUTH              240
 #define OPTION_KEYGEN               241
 
+#define OPTION_NEXT_HOP         242
+#define OPTION_RTPREFIX         243
+
 // Experimental implementation for address prefix length information
 // See: http://klub.com.pl/dhcpv6/doc/draft-mrugalski-addropts-XX-2007-04-17.txt
 #define OPTION_ADDRPARAMS           251
 
+// draft-mrugalski-remote-dhcpv6-00
+#define OPTION_NEIGHBORS 254
+
 // -- Query types (RFC5007) --
 typedef enum {
     QUERY_BY_ADDRESS = 1,
     QUERY_BY_CLIENTID = 2
 } ELeaseQueryType;
 
-
-// --- experimental: tunnel-mode ---
-#define OPTION_VENDORSPEC_TUNNEL_TYPE 1
-#define OPTION_VENDORSPEC_ENDPOINT    2
-
 // --- Option lengths --
 // (value of the len field, so actual option length is +4 bytes)
 #define OPTION_ELAPSED_TIME_LEN     2
 #define OPTION_INFORMATION_REFRESH_TIME_LEN         4
 
-// --- Status Codes --- 
-#define STATUSCODE_SUCCESS       0
-#define STATUSCODE_UNSPECFAIL    1
-#define STATUSCODE_NOADDRSAVAIL  2
-#define STATUSCODE_NOBINDING     3
-#define STATUSCODE_NOTONLINK     4
-#define STATUSCODE_USEMULTICAST  5
-#define STATUSCODE_NOPREFIXAVAIL 6 
+// --- Status Codes ---
+#define STATUSCODE_SUCCESS          0
+#define STATUSCODE_UNSPECFAIL       1
+#define STATUSCODE_NOADDRSAVAIL     2
+#define STATUSCODE_NOBINDING        3
+#define STATUSCODE_NOTONLINK        4
+#define STATUSCODE_USEMULTICAST     5
+#define STATUSCODE_NOPREFIXAVAIL    6
 // Leasequery status codes
 #define STATUSCODE_UNKNOWNQUERYTYPE 7
-#define STATUSCODE_MALFORMEDQUERY 8
-#define STATUSCODE_NOTCONFIGURED 9
-#define STATUSCODE_NOTALLOWED    10
+#define STATUSCODE_MALFORMEDQUERY   8
+#define STATUSCODE_NOTCONFIGURED    9
+#define STATUSCODE_NOTALLOWED       10
 
-// INFINITY + 1 is 0. Hihi, cool
+// INFINITY + 1 is 0. That's cool!
 #define DHCPV6_INFINITY (unsigned) 0xffffffff
 
-// How long should we wait before we assume that OS detected duplicated addresses (in secs)
-#define DADTIMEOUT (unsigned) 3
-
-// addresses reported as DECLINED are not used for 2 hours
-#define DECLINED_TIMEOUT (unsigned) 7200
-
-// DHCPv6 server default values
-#define SERVER_DEFAULT_DOMAIN ""
-#define SERVER_DEFAULT_TIMEZONE ""
-#define SERVER_DEFAULT_CLNTMAXLEASE ULONG_MAX
-#define SERVER_DEFAULT_IFACEMAXLEASE ULONG_MAX
-#define SERVER_DEFAULT_PREFERENCE 0
-#define SERVER_DEFAULT_RAPIDCOMMIT false
-
-#define SERVER_DEFAULT_MIN_T1    5
-#define SERVER_DEFAULT_MAX_T1    3600      /* 1 hour */
-#define SERVER_DEFAULT_MIN_T2    10
-#define SERVER_DEFAULT_MAX_T2    5400      /* 1,5 hour */
-#define SERVER_DEFAULT_MIN_PREF  7200      /* 2 hours */
-#define SERVER_DEFAULT_MAX_PREF  86400     /* 1 day */
-#define SERVER_DEFAULT_MIN_VALID 10800     /* 3 hours */
-#define SERVER_DEFAULT_MAX_VALID 172800    /* 2 days */
-#define SERVER_DEFAULT_CLASS_SHARE 100
-#define SERVER_DEFAULT_CLASS_MAX_LEASE ULONG_MAX
-#define SERVER_DEFAULT_TA_PREF_LIFETIME 3600
-#define SERVER_DEFAULT_TA_VALID_LIFETIME 7200
-#define SERVER_DEFAULT_CACHE_SIZE 1048576   /* cache size, specified in bytes */
-#define CLIENT_DEFAULT_T1 ULONG_MAX
-#define CLIENT_DEFAULT_T2 ULONG_MAX
-
-#define CLIENT_DEFAULT_UNICAST false
-#define CLIENT_DEFAULT_RAPID_COMMIT false
-
-#define CLIENT_DEFAULT_PREFIX_LENGTH 64
-#define CLIENT_DEFAULT_DIGEST DIGEST_NONE
-
 enum ETentative {
     TENTATIVE_UNKNOWN = -1,
     TENTATIVE_NO      = 0,
@@ -240,15 +208,24 @@ enum ETentative {
 };
 
 enum EState {
-    STATE_NOTCONFIGURED, 
-    STATE_INPROCESS, 
-    STATE_CONFIGURED, 
-    STATE_FAILED, 
-    STATE_DISABLED, 
+    STATE_NOTCONFIGURED,
+    STATE_INPROCESS,
+    STATE_CONFIGURED,
+    STATE_FAILED,
+    STATE_DISABLED,
     STATE_CONFIRMME,
-    STATE_TENTATIVECHECK, 
+    STATE_TENTATIVECHECK,
     STATE_TENTATIVE};
 
+// specifies server behavior, when receiving unknown FQDN
+enum EUnknownFQDNMode {
+    UNKNOWN_FQDN_REJECT = 0,      // reject unknown FQDNs (do not assign a name from pool)
+    UNKKOWN_FQDN_ACCEPT_POOL = 1, // assign other name available in pool
+    UNKNOWN_FQDN_ACCEPT = 2,      // accept unknown FQDNs
+    UKNNOWN_FQDN_APPEND = 3,      // accept, but append defined domain suffix
+    UKNNOWN_FQDN_PROCEDURAL = 4   // generate name procedurally, append defined domain suffix
+};
+
 // FQDN option flags
 #define FQDN_N 0x4
 #define FQDN_O 0x2
@@ -259,7 +236,7 @@ enum EState {
 #define ADDRPARAMS_MASK_ANYCAST   0x02
 #define ADDRPARAMS_MASK_MULTICAST 0x04
 
-    
+
 int allowOptInOpt(int msgType, int optOut, int optIn);
 int allowOptInMsg(int msgType, int optType);
 
@@ -289,21 +266,21 @@ int allowOptInMsg(int msgType, int optType);
 #endif
 
 enum DigestTypes {
-        DIGEST_NONE = 0,
-        DIGEST_PLAIN = 1,
-        DIGEST_HMAC_MD5 = 2,
-        DIGEST_HMAC_SHA1 = 3,
-        DIGEST_HMAC_SHA224 = 4,
-        DIGEST_HMAC_SHA256 = 5,
-        DIGEST_HMAC_SHA384 = 6,
-        DIGEST_HMAC_SHA512 = 7,
-        //this must be last, increase it if necessary
-        DIGEST_INVALID = 8
+	DIGEST_NONE = 0,
+	DIGEST_PLAIN = 1,
+	DIGEST_HMAC_MD5 = 2,
+	DIGEST_HMAC_SHA1 = 3,
+	DIGEST_HMAC_SHA224 = 4,
+	DIGEST_HMAC_SHA256 = 5,
+	DIGEST_HMAC_SHA384 = 6,
+	DIGEST_HMAC_SHA512 = 7,
+	//this must be last, increase it if necessary
+	DIGEST_INVALID = 8
 };
 
 unsigned getDigestSize(enum DigestTypes type);
 char *getDigestName(enum DigestTypes type);
-        
+
 // key is generated this way:
 // key = HMAC-SHA1 (AAA-key, {Key Generation Nonce || client identifier})
 // so it's size is always size of HMAC-SHA1 result which is 160bits = 20bytes
