@@ -13,8 +13,6 @@
 #include <iostream>
 #include <string>
 #include "SmartPtr.h"
-#include "SrvIfaceMgr.h"
-#include "SrvTransMgr.h"
 
 using namespace std;
 class TDHCPServer
@@ -30,10 +28,6 @@ class TDHCPServer
 
   private:
     bool IsDone;
-    SmartPtr<TSrvIfaceMgr> IfaceMgr;
-    SmartPtr<TSrvAddrMgr> AddrMgr;
-    SmartPtr<TSrvCfgMgr> CfgMgr;
-    SmartPtr<TSrvTransMgr> TransMgr;
 };
 
 #endif
