@@ -8,36 +8,30 @@
  *
  * Released under GNU GPL v2 licence
  *
- * $Id: Portable.h,v 1.101 2009-03-09 22:27:23 thomson Exp $
+ * $Id: Portable.h,v 1.102 2009-07-22 20:19:08 thomson Exp $
  */	
 
 #ifndef PORTABLE_H
 #define PORTABLE_H
 
-/* #define DIBBLER_VERSION "0.7.3-CVS (" __DATE__ " " __TIME__ ")" */
-#define DIBBLER_VERSION "0.7.3"
+/* #define DIBBLER_VERSION "0.8.0-git (" __DATE__ " " __TIME__ ")" */
+#define DIBBLER_VERSION "0.8.1"
 
 #define DIBBLER_COPYRIGHT1 "| Dibbler - a portable DHCPv6, version " DIBBLER_VERSION
 #define DIBBLER_COPYRIGHT2 "| Authors : Tomasz Mrugalski<thomson(at)klub.com.pl>,Marek Senderski<msend(at)o2.pl>"
 #define DIBBLER_COPYRIGHT3 "| Licence : GNU GPL v2 only. Developed at Gdansk University of Technology."
 #define DIBBLER_COPYRIGHT4 "| Homepage: http://klub.com.pl/dhcpv6/"
 
-#ifdef LINUX
-#include <netinet/in.h>
-#include <stdio.h>
-#include <stdlib.h>
-#include <unistd.h>
-#include <resolv.h>
-#include <sys/socket.h>
-#include <sys/select.h>
-#include <sys/time.h>
+#ifdef WIN32
+#include <winsock2.h>
+#endif
+#if defined(LINUX) || defined(BSD)
 #include <arpa/inet.h>
-#include <ctype.h>
-#include <stdarg.h>
-#include <string.h>
-#endif 
+#endif
 
 #ifdef WIN32
+#define strcasecmp strcmpi
+
 #ifndef uint8_t
 #define uint8_t  unsigned char
 #endif
@@ -57,10 +51,35 @@
 #define snprintf _snprintf
 #endif
 
-#ifdef MACOS
+#ifdef BSD
 #include <stdint.h>
 #endif
 
+/* this should look like this: 
+uint16_t readUint16(uint8_t* buf);
+uint8_t * writeUint16(uint8_t* buf, uint16_t word);
+uint32_t readUint32(uint8_t* buf);
+uint8_t* writeUint32(uint8_t* buf, uint32_t dword);
+uint64_t readUint64(uint8_t* buf);
+uint8_t* writeUint64(uint8_t* buf, uint64_t qword); */
+
+/* due to poor type usage (char* instead of uint8_t*), we need to stick with
+   char* for now. Changing to uint8_t would require rewriting large parts of the code */
+#define BUFFER_TYPE char
+
+#ifdef __cplusplus 
+extern "C" {
+#endif
+    uint16_t readUint16(const BUFFER_TYPE * buf);
+    BUFFER_TYPE * writeUint16(BUFFER_TYPE * buf, uint16_t word);
+    uint32_t readUint32(const BUFFER_TYPE * buf);
+    BUFFER_TYPE * writeUint32(BUFFER_TYPE * buf, uint32_t dword);
+    uint64_t readUint64(const BUFFER_TYPE * buf);
+    BUFFER_TYPE * writeUint64(BUFFER_TYPE * buf, uint64_t qword);
+#ifdef __cplusplus 
+}
+#endif
+
 #define DEFAULT_UMASK 027
 
 /**********************************************************************/
@@ -82,6 +101,7 @@ struct iface {
     int  linkaddrcount;            /* number of assigned IPv6 link local addresses */
     char *globaladdr;              /* global IPv6 addresses */
     int  globaladdrcount;          /* number of global IPV6 addresses */
+    int  link_state;               /* used in link change detection routines */
     unsigned int flags;            /* look IF_xxx in portable.h */
     struct iface* next;            /* structure describing next iface in system */
 };
@@ -90,7 +110,9 @@ struct iface {
 
 struct link_state_notify_t
 {
-    int ifindex[MAX_LINK_STATE_CHANGES_AT_ONCE]; /* indexes of interfaces that has changed. Only non-zero values will be used */
+    int ifindex[MAX_LINK_STATE_CHANGES_AT_ONCE]; /* indexes of interfaces that has changed. 
+                                                    Only non-zero values will be used */
+    int stat[MAX_LINK_STATE_CHANGES_AT_ONCE];
     int cnt;  /* number of iterface indexes filled */
 };
 
@@ -118,13 +140,14 @@ struct link_state_notify_t
 #define REQIFACEMGR_FILE  "requestor-IfaceMgr.xml"
 
 #define DNSUPDATE_DEFAULT_TTL "2h"
+#define DNSUPDATE_DEFAULT_TIMEOUT 1000 /* in ms */
 #define INACTIVE_MODE_INTERVAL 3 /* 3 seconds */
 
 #define REQLOG_FILE        "dibbler-requestor.log"
 
 #ifdef WIN32
 #define WORKDIR            ".\\"
-#define DEFAULT_SCRIPTSDIR ".\\scritps"
+#define DEFAULT_SCRIPT     ""
 #define CLNTCONF_FILE 	   "client.conf"
 #define SRVCONF_FILE       "server.conf"
 #define RELCONF_FILE       "relay.conf"
@@ -136,7 +159,7 @@ struct link_state_notify_t
 
 #ifdef LINUX
 #define WORKDIR            "/var/lib/dibbler"
-#define DEFAULT_SCRIPTSDIR "/var/lib/dibbler/scripts"
+#define DEFAULT_SCRIPT     ""
 #define CLNTCONF_FILE      "/etc/dibbler/client.conf"
 #define SRVCONF_FILE       "/etc/dibbler/server.conf"
 #define RELCONF_FILE       "/etc/dibbler/relay.conf"
@@ -154,9 +177,9 @@ struct link_state_notify_t
 #define NULLFILE           "/dev/null"
 #endif
 
-#ifdef MACOS
+#ifdef BSD
 #define WORKDIR            "/var/lib/dibbler"
-#define DEFAULT_SCRIPTSDIR "/var/lib/dibbler/scripts"
+#define DEFAULT_SCRIPT     ""
 #define CLNTCONF_FILE      "/etc/dibbler/client.conf"
 #define SRVCONF_FILE       "/etc/dibbler/server.conf"
 #define RELCONF_FILE       "/etc/dibbler/relay.conf"
@@ -184,6 +207,12 @@ struct link_state_notify_t
 #define OPTION_NISP_SERVERS_FILENAME "option-nisplus-servers"
 #define OPTION_NISP_DOMAIN_FILENAME  "option-nisplus-domain"
 
+/* --- bulk leasequery --- */
+#define BULKLQ_ACCEPT false
+#define BULKLQ_TCP_PORT 547
+#define BULKLQ_MAX_CONNS 10
+#define BULKLQ_TIMEOUT 300
+
 /* ********************************************************************** */
 /* *** interface flags ************************************************** */
 /* ********************************************************************** */
@@ -205,12 +234,11 @@ struct link_state_notify_t
 #define IF_MULTICAST	      0x1000
 #endif
 
-#ifdef MACOS
-/* dumb guesses for now. if_list_get() must be implemented for real */
+#ifdef BSD
 #define IF_UP        0x1
-#define IF_LOOPBACK  0x2
-#define IF_RUNNING   0x4
-#define IF_MULTICAST 0x8 
+#define IF_LOOPBACK  0x8
+#define IF_RUNNING   0x40
+#define IF_MULTICAST 0x8000
 #endif
 
 /* ********************************************************************** */
@@ -263,7 +291,7 @@ extern "C" {
 
     /* add address to interface */
     extern int ipaddr_add(const char* ifacename, int ifindex, const char* addr, 
-			  unsigned long pref, unsigned long valid, int prefixLength);
+unsigned long pref, unsigned long valid, int prefixLength);
     extern int ipaddr_update(const char* ifacename, int ifindex, const char* addr,
 			     unsigned long pref, unsigned long valid, int prefixLength);
     extern int ipaddr_del(const char* ifacename, int ifindex, const char* addr, int prefixLength);
@@ -314,7 +342,6 @@ extern "C" {
     extern int nisplusdomain_set(const char* ifname, int ifindex, const char* domain);
     extern int nisplusdomain_del(const char* ifname, int ifindex, const char* domain);
 
-    extern int prefix_forwarding_enabled();
     extern int prefix_add(const char* ifname, int ifindex, const char* prefixPlain, int prefixLength,
 			  unsigned long prefered, unsigned long valid);
     extern int prefix_update(const char* ifname, int ifindex, const char* prefixPlain, int prefixLength,
@@ -324,6 +351,8 @@ extern "C" {
     char * getAAAKey(uint32_t SPI, uint32_t *len); /* reads AAA key from a file */
     char * getAAAKeyFilename(uint32_t SPI); /* which file? use this function to find out */
     uint32_t getAAASPIfromFile();
+
+    int execute(const char *filename, const char * argv[], const char *env[]);
     
 #ifdef __cplusplus
 }
