@@ -8,10 +8,7 @@
  *
  * $Id: OptAddrLst.h,v 1.2 2008-08-29 00:07:30 thomson Exp $
  *
- * $Log: OptAddrLst.h,v $
- * Revision 1.2  2008-08-29 00:07:30  thomson
- * Temporary license change(GPLv2 or later -> GPLv2 only)
- *
+ * $Log: not supported by cvs2svn $
  * Revision 1.1  2004-11-02 01:23:13  thomson
  * Initial revision
  *
@@ -29,16 +26,16 @@ class TOptAddrLst : public TOpt
 {
 public:
     TOptAddrLst(int type, List(TIPv6Addr) lst, TMsg* parent);
-    TOptAddrLst(int type, char *&buf, int &bufsize, TMsg* parent);
+    TOptAddrLst(int type, const char *buf, unsigned short len, TMsg* parent);
     char * storeSelf( char* buf);
     int getSize();
     void firstAddr();
-    SmartPtr<TIPv6Addr> getAddr();
+    SPtr<TIPv6Addr> getAddr();
     int countAddr();
     bool isValid();
+    virtual bool doDuties() { return true; } // does nothing on its own
+    std::string getPlain();
 protected:
     List(TIPv6Addr) AddrLst;
-    bool Valid;
-
 };
 #endif
