@@ -18,15 +18,17 @@
 class TOptDUID : public TOpt
 {
   public:
-    TOptDUID(int type, SmartPtr<TDUID> duid, TMsg* parent);
-    TOptDUID(int type, char* &buf, int &bufsize, TMsg* parent);
+    TOptDUID(int type, SPtr<TDUID> duid, TMsg* parent);
+    TOptDUID(int type, const char* buf, int len, TMsg* parent);
     int getSize();
 
     char * storeSelf(char* buf);
-    SmartPtr<TDUID> getDUID();
+    bool doDuties() { return true; }
+    SPtr<TDUID> getDUID();
     bool isValid();
+    std::string getPlain() { if (DUID) return DUID->getPlain(); else return std::string(""); }
   protected:
-    SmartPtr<TDUID> DUID;
+    SPtr<TDUID> DUID;
 };
 
 #endif
