@@ -8,10 +8,7 @@
  *
  * $Id: OptStringLst.h,v 1.1 2004-11-02 01:23:13 thomson Exp $
  *
- * $Log: OptStringLst.h,v $
- * Revision 1.1  2004-11-02 01:23:13  thomson
- * Initial revision
- *
+ * $Log: not supported by cvs2svn $
  */
 
 #ifndef OPTSTRINGLST_H
@@ -25,13 +22,14 @@ class TOptStringLst : public TOpt
 {
 public:
     TOptStringLst(int type, List(string) strLst, TMsg* parent);
-    TOptStringLst(int type, char *&buf, int &bufsize, TMsg* parent);
+    TOptStringLst(int type, const char *buf, unsigned short bufsize, TMsg* parent);
     char * storeSelf( char* buf);
     int getSize();
-    void firstString();
-    string getString();
+    //void firstString();
+    //string getString();
     int countString();
-
+    bool doDuties() { return true; }
+    virtual std::string getPlain();
 protected:
     List(string) StringLst;
 };
