@@ -52,6 +52,10 @@
 #define IPV6_RECVPKTINFO IPV6_PKTINFO
 #endif
 
+#define ADDROPER_DEL 0
+#define ADDROPER_ADD 1
+#define ADDROPER_UPDATE 2
+
 struct rtnl_handle rth;
 char Message[1024] = {0};
 
@@ -167,6 +171,7 @@ struct iface * if_list_get()
 #endif
 
 	tmp = malloc(sizeof(struct iface));
+	memset(tmp, 0, sizeof(struct iface));
 	snprintf(tmp->name,MAX_IFNAME_LENGTH,"%s",(char*)RTA_DATA(tb[IFLA_IFNAME]));
 	tmp->id=ifi->ifi_index;
 	tmp->flags=ifi->ifi_flags;
@@ -283,11 +288,20 @@ void ipaddr_global_get(int *count, char **bufPtr, int ifindex, struct nlmsg_list
     *bufPtr = buf;
 }
 
-/*
- * adds or deletes addresses to interface
+/** 
+ * adds, updates or deletes addresses to interface
+ * 
+ * @param addr 
+ * @param ifacename 
+ * @param prefixLen 
+ * @param preferred 
+ * @param valid 
+ * @param mode - 0-delete, 1-add, 2-update
+ * 
+ * @return 
  */
-
-int ipaddr_add_or_del(const char * addr, const char *ifacename, int prefixLen, int add)
+int ipaddr_add_or_del(const char * addr, const char *ifacename, int prefixLen, 
+                      unsigned long preferred, unsigned long valid, int mode)
 {
     struct rtnl_handle rth;
     struct {
@@ -300,6 +314,7 @@ int ipaddr_add_or_del(const char * addr, const char *ifacename, int prefixLen, i
     int local_len = 0;
     int peer_len = 0;
     int scoped = 0;
+    struct ifa_cacheinfo ci;
 
 #ifdef LOWLEVEL_DEBUG
     printf("### iface=%s, addr=%s, add=%d ###\n", ifacename, addr, add);
@@ -307,9 +322,20 @@ int ipaddr_add_or_del(const char * addr, const char *ifacename, int prefixLen, i
     
     memset(&req, 0, sizeof(req));
     req.n.nlmsg_len = NLMSG_LENGTH(sizeof(struct ifaddrmsg));
-    req.n.nlmsg_flags = NLM_F_REQUEST;
-    if (add==1) req.n.nlmsg_type = RTM_NEWADDR; /* add address */
-    else req.n.nlmsg_type = RTM_DELADDR;        /* del address */
+    switch (mode) {
+    case ADDROPER_DEL:
+        req.n.nlmsg_type = RTM_DELADDR; /* del address */
+        req.n.nlmsg_flags = NLM_F_REQUEST;
+        break;
+    case ADDROPER_ADD:
+        req.n.nlmsg_type = RTM_NEWADDR; /* add address */
+        req.n.nlmsg_flags = NLM_F_REQUEST |NLM_F_CREATE|NLM_F_EXCL;
+        break;
+    case ADDROPER_UPDATE:
+        req.n.nlmsg_type = RTM_NEWADDR; /* update address */
+        req.n.nlmsg_flags = NLM_F_REQUEST | NLM_F_REPLACE;
+        break;
+    }
     req.ifa.ifa_family = AF_INET6;
     req.ifa.ifa_flags = 0;
     req.ifa.ifa_prefixlen = prefixLen;
@@ -318,6 +344,11 @@ int ipaddr_add_or_del(const char * addr, const char *ifacename, int prefixLen, i
     
     addattr_l(&req.n, sizeof(req), IFA_LOCAL, &lcl.data, lcl.bytelen);
     local_len = lcl.bytelen;
+
+    memset(&ci, 0, sizeof(ci));
+    ci.ifa_valid = valid;
+    ci.ifa_prefered = preferred;
+    addattr_l(&req.n, sizeof(req), IFA_CACHEINFO, &ci, sizeof(ci));
     
     if (peer_len == 0 && local_len) {
 	peer = lcl;
@@ -345,20 +376,23 @@ int ipaddr_add_or_del(const char * addr, const char *ifacename, int prefixLen, i
 int ipaddr_add(const char * ifacename, int ifaceid, const char * addr, unsigned long pref,
 	       unsigned long valid, int prefixLength)
 {
-    return ipaddr_add_or_del(addr,ifacename, prefixLength, 1);
+    return ipaddr_add_or_del(addr,ifacename, prefixLength, pref, valid, ADDROPER_ADD);
 }
 
 int ipaddr_update(const char* ifacename, int ifindex, const char* addr,
 		  unsigned long pref, unsigned long valid, int prefixLength)
 {
     /* FIXME: Linux kernel currently does not provide API for dynamic adresses */
+
+    return ipaddr_add_or_del(addr, ifacename, prefixLength, pref, valid, ADDROPER_UPDATE);
+
     return LOWLEVEL_NO_ERROR;
 }
 
 
 int ipaddr_del(const char * ifacename, int ifaceid, const char * addr, int prefixLength)
 {
-    return ipaddr_add_or_del(addr,ifacename, prefixLength, 0);
+    return ipaddr_add_or_del(addr,ifacename, prefixLength, 0/*pref*/, 0/*valid*/, ADDROPER_DEL);
 }
 
 int sock_add(char * ifacename,int ifaceid, char * addr, int port, int thisifaceonly, int reuse)
