@@ -9,14 +9,19 @@
  *
  */
 
+#define _BSD_SOURCE
+#define _POSIX_SOURCE
+
 #include <stdio.h>
+#include <unistd.h>
+#include <ctype.h>
+#include <errno.h>
+#include <string.h>
+#include <stdlib.h>
 #include <linux/types.h>
 #include <sys/socket.h>
 #include <linux/rtnetlink.h>
-#include <ctype.h>
-#include <errno.h>
-#include "sys/stat.h"
-#include "errno.h"
+#include <sys/stat.h>
 #include "Portable.h"
 
 #define CR 0x0a
@@ -364,12 +369,14 @@ int prefix_forwarding_enabled()
  * to all other up, running and multicast capable interfaces.
  * In both cases, radvd.conf file will be created.
  * 
- * @param ifname 
- * @param ifindex 
- * @param prefixPlain 
- * @param prefixLength 
+ * @param ifname interface name
+ * @param ifindex interface index
+ * @param prefixPlain prefix (specified in human readable format)
+ * @param prefixLength prefix length
+ * @param prefered preferred lifetime
+ * @param valid valid lifetime
  * 
- * @return 
+ * @return negative error code or 0 if successful
  */
 int prefix_add(const char* ifname, int ifindex, const char* prefixPlain, int prefixLength,
 	       unsigned long prefered, unsigned long valid)
@@ -402,7 +409,7 @@ int prefix_add(const char* ifname, int ifindex, const char* prefixPlain, int pre
     fprintf(f, "     prefix %s/%d", prefixPlain, prefixLength);
     fprintf(f, "     { \n");
     fprintf(f, "         AdvOnLink on;\n");
-    fprintf(f, "         AdvAutonomous false;\n");
+    fprintf(f, "         AdvAutonomous on;\n");
     fprintf(f, "     };\n");
     fprintf(f, "};\n");
     fprintf(f, "### %s end ###\n", ifname);
