@@ -21,6 +21,8 @@
 TDHCPClient * clntPtr;
 TClntService StaticService;
 
+using namespace std;
+
 TClntService::TClntService() 
     :TWinService("DHCPv6Client","Dibbler - a DHCPv6 client",SERVICE_AUTO_START,
 		 "tcpip6\0winmgmt\0",
@@ -47,7 +49,7 @@ EServiceState TClntService::ParseStandardArgs(int argc,char* argv[])
 	
 		if (strncmp(argv[n], "-d",2)==0) {
 			if (n+1==argc) {
-				cout << "-d is a last parameter (additional filepath required)" << endl;
+				std::cout << "-d is a last parameter (additional filepath required)" << std::endl;
 				return INVALID; // this is last parameter
 			}
 			n++;
@@ -130,10 +132,7 @@ TClntService::~TClntService(void)
 }
 
 /*
- * $Log: ClntService.cpp,v $
- * Revision 1.24  2008-08-30 20:41:06  thomson
- * General WIN32 cleanup.
- *
+ * $Log: not supported by cvs2svn $
  * Revision 1.23  2006-05-01 13:56:28  thomson
  * winsock2.h include added.
  *
