@@ -8,20 +8,6 @@
  *
  * $Id: RelCfgIface.h,v 1.4 2008-08-29 00:07:31 thomson Exp $
  *
- * $Log: RelCfgIface.h,v $
- * Revision 1.4  2008-08-29 00:07:31  thomson
- * Temporary license change(GPLv2 or later -> GPLv2 only)
- *
- * Revision 1.3  2007-05-01 12:03:13  thomson
- * Support for interface-id location added.
- *
- * Revision 1.2  2007-03-07 02:37:10  thomson
- * Experimental support for guess-mode.
- *
- * Revision 1.1  2005-01-11 22:53:35  thomson
- * Relay skeleton implemented.
- *
- *
  */
 
 class TRelCfgIface;
@@ -49,12 +35,12 @@ public:
     string getName();
     string getFullName();
 
-    SmartPtr<TIPv6Addr> getServerUnicast();
-    SmartPtr<TIPv6Addr> getClientUnicast();
+    SPtr<TIPv6Addr> getServerUnicast();
+    SPtr<TIPv6Addr> getClientUnicast();
     bool getServerMulticast();
     bool getClientMulticast();
 
-    void setOptions(SmartPtr<TRelParsGlobalOpt> opt);
+    void setOptions(SPtr<TRelParsGlobalOpt> opt);
     
     unsigned char getPreference();
     int getInterfaceID();
@@ -64,8 +50,8 @@ private:
     int	ID;
     int InterfaceID; // value of interface-id option (optional)
 
-    SmartPtr<TIPv6Addr> ClientUnicast;
-    SmartPtr<TIPv6Addr> ServerUnicast;
+    SPtr<TIPv6Addr> ClientUnicast;
+    SPtr<TIPv6Addr> ServerUnicast;
     bool ClientMulticast;
     bool ServerMulticast;
 };
