@@ -5,11 +5,9 @@
  *
  * released under GNU GPL v2 only licence
  *
- * $Id: RelIfaceMgr.cpp,v 1.18 2008-08-29 00:07:32 thomson Exp $
- *
  */
 
-#include "RelCommon.h"
+#include <fstream>
 #include "Logger.h"
 #include "IPv6Addr.h"
 #include "Iface.h"
@@ -20,6 +18,9 @@
 #include "RelMsgRelayForw.h"
 #include "RelMsgRelayRepl.h"
 #include "RelOptInterfaceID.h"
+#include "Portable.h"
+
+TRelIfaceMgr * TRelIfaceMgr::Instance = 0;
 
 /*
  * constructor. Do nothing particular, just invoke IfaceMgr constructor
@@ -42,23 +43,24 @@ void TRelIfaceMgr::dump()
 
 /**
  * sends data to client. Uses multicast address as source
- * @param iface - interface ID
- * @param msg - buffer containing message ready to send
- * @param size - size of message
- * @param addr - destination address
+ * @param ifindex interface ID
+ * @param data    buffer containing message ready to send
+ * @param dataLen size of message
+ * @param addr    destination address
+ * @param port    UDP port to send the data to
  * returns true if message was send successfully
  */
-bool TRelIfaceMgr::send(int ifindex, char *data, int dataLen, 
-			SmartPtr<TIPv6Addr> addr, int port) {
+bool TRelIfaceMgr::send(int ifindex, char *data, int dataLen, SPtr<TIPv6Addr> addr, int port)
+{
     // find this interface
-    SmartPtr<TIfaceIface> iface = this->getIfaceByID(ifindex);
+    SPtr<TIfaceIface> iface = this->getIfaceByID(ifindex);
     if (!iface) {
 	Log(Error)  << "Send failed: No such interface id=" << ifindex << LogEnd;
 	return false;
     }
 
     // find this socket
-    SmartPtr<TIfaceSocket> ptrSocket;
+    SPtr<TIfaceSocket> ptrSocket;
     iface->firstSocket();
     ptrSocket = iface->getSocket();
     if (!ptrSocket) {
@@ -77,15 +79,15 @@ bool TRelIfaceMgr::send(int ifindex, char *data, int dataLen,
  * reads messages from all interfaces
  * it's wrapper around IfaceMgr::select(...) method
  * @param timeout - how long can we wait for packets?
- * returns SmartPtr to message object
+ * returns SPtr to message object
  */
-SmartPtr<TRelMsg> TRelIfaceMgr::select(unsigned long timeout) {
+SPtr<TRelMsg> TRelIfaceMgr::select(unsigned long timeout) {
     
     // static buffer speeds things up
     static char data[2048];
     int dataLen=2048;
 
-    SmartPtr<TIPv6Addr> peer (new TIPv6Addr());
+    SPtr<TIPv6Addr> peer (new TIPv6Addr());
     int sockid;
     int msgtype;
 
@@ -99,9 +101,9 @@ SmartPtr<TRelMsg> TRelIfaceMgr::select(unsigned long timeout) {
 	
 	// check message type
 	msgtype = data[0];
-	SmartPtr<TMsg> ptr;
-	SmartPtr<TIfaceIface> iface;
-	SmartPtr<TIfaceSocket> sock;
+	SPtr<TMsg> ptr;
+	SPtr<TIfaceIface> iface;
+	SPtr<TIfaceSocket> sock;
 
 	// get interface
 	iface = this->getIfaceBySocket(sockid);
@@ -122,29 +124,29 @@ SmartPtr<TRelMsg> TRelIfaceMgr::select(unsigned long timeout) {
     return 0;
 }
 
-SmartPtr<TRelMsg> TRelIfaceMgr::decodeRelayForw(SmartPtr<TIfaceIface> iface, 
-						SmartPtr<TIPv6Addr> peer, 
+SPtr<TRelMsg> TRelIfaceMgr::decodeRelayForw(SPtr<TIfaceIface> iface, 
+						SPtr<TIPv6Addr> peer, 
 						char * data, int dataLen) {
     int ifindex = iface->getID();
-    SmartPtr<TRelMsg> msg = new TRelMsgRelayForw(this->Ctx, ifindex, peer, data, dataLen);
+    SPtr<TRelMsg> msg = new TRelMsgRelayForw(ifindex, peer, data, dataLen);
     return msg;
 }
 
-SmartPtr<TRelMsg> TRelIfaceMgr::decodeGeneric(SmartPtr<TIfaceIface> iface, 
-					      SmartPtr<TIPv6Addr> peer, 
+SPtr<TRelMsg> TRelIfaceMgr::decodeGeneric(SPtr<TIfaceIface> iface, 
+					      SPtr<TIPv6Addr> peer, 
 					      char * buf, int bufsize) {
     int ifindex = iface->getID();
-    return new TRelMsgGeneric(this->Ctx, ifindex, peer, buf, bufsize);
+    return new TRelMsgGeneric(ifindex, peer, buf, bufsize);
 }
 
-SmartPtr<TRelMsg> TRelIfaceMgr::decodeRelayRepl(SmartPtr<TIfaceIface> iface, 
-						SmartPtr<TIPv6Addr> peer, 
+SPtr<TRelMsg> TRelIfaceMgr::decodeRelayRepl(SPtr<TIfaceIface> iface, 
+						SPtr<TIPv6Addr> peer, 
 						char * buf, int bufsize) {
-    SmartPtr<TIPv6Addr> linkAddrTbl[HOP_COUNT_LIMIT];
-    SmartPtr<TIPv6Addr> peerAddrTbl[HOP_COUNT_LIMIT];
-    SmartPtr<TRelOptInterfaceID> interfaceIDTbl[HOP_COUNT_LIMIT];
+    SPtr<TIPv6Addr> linkAddrTbl[HOP_COUNT_LIMIT];
+    SPtr<TIPv6Addr> peerAddrTbl[HOP_COUNT_LIMIT];
+    SPtr<TRelOptInterfaceID> interfaceIDTbl[HOP_COUNT_LIMIT];
     int hopTbl[HOP_COUNT_LIMIT];
-    SmartPtr<TRelOptInterfaceID> ptrIfaceID;
+    SPtr<TRelOptInterfaceID> ptrIfaceID;
     char * relayBuf=0;
     int relayLen = 0;
     int relays=0;
@@ -157,16 +159,16 @@ SmartPtr<TRelMsg> TRelIfaceMgr::decodeRelayRepl(SmartPtr<TIfaceIface> iface,
 
     // char type = buf[0]; // ignore it
     int hopCount = buf[1]; // this one is not currently needed either
-    SmartPtr<TIPv6Addr> linkAddr = new TIPv6Addr(buf+2,false);
-    SmartPtr<TIPv6Addr> peerAddr = new TIPv6Addr(buf+18, false);
+    SPtr<TIPv6Addr> linkAddr = new TIPv6Addr(buf+2,false);
+    SPtr<TIPv6Addr> peerAddr = new TIPv6Addr(buf+18, false);
     buf+=34;
     bufsize-=34;
     
     // options: only INTERFACEID and RELAY_MSG are allowed
     while (bufsize>=4) {
 
-	unsigned short code = ntohs( *((unsigned short*) (buf)));
-	unsigned short len  = ntohs( *((unsigned short*) (buf+2)));
+	unsigned short code = readUint16(buf);
+	unsigned short len  = readUint16(buf + sizeof(uint16_t));
 	if (len>bufsize) {
 	    Log(Error) << "Message RELAY-REPL truncated. There are " << (bufsize-len) 
 		       << " bytes left to parse. Message dropped." << LogEnd;
@@ -197,7 +199,7 @@ SmartPtr<TRelMsg> TRelIfaceMgr::decodeRelayRepl(SmartPtr<TIfaceIface> iface,
 	    bufsize -= relayLen;
 	    break;
 	default:
-	    SPtr<TRelOptEcho> echo = Ctx->CfgMgr->getEcho();
+	    SPtr<TRelOptEcho> echo = RelCfgMgr().getEcho();
 	    if (echo && echo->isOption(code)) {
 		Log(Notice) << "Received echoed back option " << code << "." << LogEnd;
 	    } else {
@@ -215,16 +217,16 @@ SmartPtr<TRelMsg> TRelIfaceMgr::decodeRelayRepl(SmartPtr<TIfaceIface> iface,
     Log(Cont) << LogEnd;
 
     if (!ptrIfaceID) {
-	if (!Ctx->CfgMgr->guessMode()) {
+	if (!RelCfgMgr().guessMode()) {
 	    /* guessMode disabled */
 	    Log(Warning) << "InterfaceID option is missing, guessMode disabled, unable to forward. Packet dropped." << LogEnd;
 	    return 0;
 	}
 
 	/* guess mode enabled, let's find any interface */
-	SmartPtr<TRelCfgIface> tmp;
-	Ctx->CfgMgr->firstIface();
-	while (tmp = Ctx->CfgMgr->getIface()) {
+	SPtr<TRelCfgIface> tmp;
+	RelCfgMgr().firstIface();
+	while (tmp = RelCfgMgr().getIface()) {
 	    if (tmp->getID() == iface->getID()) 
 		continue; // skip the interface we've received the data on
 	    break;
@@ -243,11 +245,11 @@ SmartPtr<TRelMsg> TRelIfaceMgr::decodeRelayRepl(SmartPtr<TIfaceIface> iface,
     hopTbl[relays] = hopCount;
     relays++;
 
-    SmartPtr<TRelMsg> msg;
+    SPtr<TRelMsg> msg;
     switch (relayBuf[0]) {
     case RELAY_REPL_MSG:
 	//msg = this->decodeRelayRepl(iface, peer, buf, bufsize);
-	msg = new TRelMsgRelayRepl(this->Ctx, iface->getID(), peer, relayBuf, relayLen);
+	msg = new TRelMsgRelayRepl(iface->getID(), peer, relayBuf, relayLen);
 	break;
     case RELAY_FORW_MSG:
 	Log(Error) << "RELAY_REPL contains RELAY_FORW message." << LogEnd;
@@ -260,8 +262,8 @@ SmartPtr<TRelMsg> TRelIfaceMgr::decodeRelayRepl(SmartPtr<TIfaceIface> iface,
     return (Ptr*)msg;
 }
 
-SmartPtr<TRelMsg> TRelIfaceMgr::decodeMsg(SmartPtr<TIfaceIface> iface, 
-					  SmartPtr<TIPv6Addr> peer, 
+SPtr<TRelMsg> TRelIfaceMgr::decodeMsg(SPtr<TIfaceIface> iface, 
+					  SPtr<TIPv6Addr> peer, 
 					  char * data, int dataLen) {
     if (dataLen <= 0) 
 	return 0;
@@ -290,14 +292,23 @@ SmartPtr<TRelMsg> TRelIfaceMgr::decodeMsg(SmartPtr<TIfaceIface> iface,
     }
 }
 
-void TRelIfaceMgr::setContext(TCtx *ctx)
+void TRelIfaceMgr::instanceCreate( const std::string xmlFile )
 {
-    this->Ctx = ctx;
+    if (Instance)
+      Log(Crit) << "RelIfaceMgr instance already created. Application error!" << LogEnd;
+    Instance = new TRelIfaceMgr(xmlFile);
+}
+
+TRelIfaceMgr& TRelIfaceMgr::instance()
+{
+    if (!Instance)
+      Log(Crit) << "RelIfaceMgr istance not created yet. Application error. Crashing in 3... 2... 1..." << LogEnd;
+    return *Instance;
 }
 
 ostream & operator <<(ostream & strum, TRelIfaceMgr &x) {
     strum << "<RelIfaceMgr>" << std::endl;
-    SmartPtr<TIfaceIface> ptr;
+    SPtr<TIfaceIface> ptr;
     x.IfaceLst.first();
     while ( ptr= (Ptr*) x.IfaceLst.get() ) {
 	strum << *ptr;
