@@ -8,10 +8,7 @@
  *
  * $Id: RelTransMgr.h,v 1.3 2008-08-29 00:07:33 thomson Exp $
  *
- * $Log: RelTransMgr.h,v $
- * Revision 1.3  2008-08-29 00:07:33  thomson
- * Temporary license change(GPLv2 or later -> GPLv2 only)
- *
+ * $Log: not supported by cvs2svn $
  * Revision 1.2  2005-01-13 22:45:55  thomson
  * Relays implemented.
  *
@@ -26,26 +23,27 @@ class TRelTransMgr;
 #define RELTRANSMGR_H
 
 #include <iostream>
-#include "RelCommon.h"
 #include "SmartPtr.h"
 #include "RelCfgIface.h"
 #include "RelMsg.h"
 
-using namespace std;
+#define RelTransMgr() (TRelTransMgr::instance())
 
 class TRelTransMgr
 {
     friend ostream & operator<<(ostream &strum, TRelTransMgr &x);
   public:
-    TRelTransMgr(TCtx * ctx, string xmlFile);
+    static void instanceCreate(const std::string xmlFile);
+    static TRelTransMgr& instance();
+
     ~TRelTransMgr();
 
-    bool openSocket(SmartPtr<TRelCfgIface> confIface);
+    bool openSocket(SPtr<TRelCfgIface> confIface);
 
     bool doDuties();
 
-    void relayMsg(SmartPtr<TRelMsg> msg);
-    void relayMsgRepl(SmartPtr<TRelMsg> msg);
+    void relayMsg(SPtr<TRelMsg> msg);
+    void relayMsgRepl(SPtr<TRelMsg> msg);
     void dump();
 
     bool isDone();
@@ -55,7 +53,8 @@ class TRelTransMgr
     int    getCtrlIface();
     
   private:
-    TCtx * Ctx;
+    TRelTransMgr(const std::string xmlFile);
+    static TRelTransMgr * Instance;
     string XmlFile;
     bool IsDone;
 
