@@ -8,6 +8,8 @@
  * $Id: Requestor.cpp,v 1.7 2008-09-22 17:08:54 thomson Exp $
  */
 
+#include <string.h>
+#include <stdlib.h>
 #include "Portable.h"
 #include "ReqCfgMgr.h"
 #include "Portable.h"
@@ -127,7 +129,7 @@ int main(int argc, char *argv[])
 {
     // int status = 0;
     ReqCfgMgr a;
-    memset(&a, sizeof(a), 0);
+    //memset(&a, 0 sizeof(a));
 
     initWin();
 
