@@ -12,15 +12,10 @@
  */
 
 #include <sstream>
-#ifdef WIN32
-#include <winsock2.h>
-#endif
-#ifdef LINUX
-#include <netinet/in.h>
-#endif
-
+#include "Portable.h"
 #include "SrvMsg.h"
 #include "SrvTransMgr.h"
+#include "OptEmpty.h"
 #include "SrvOptClientIdentifier.h"
 #include "SrvOptServerIdentifier.h"
 #include "SrvOptIA_NA.h"
@@ -30,13 +25,10 @@
 #include "SrvOptElapsed.h"
 #include "SrvOptServerUnicast.h"
 #include "SrvOptStatusCode.h"
-#include "SrvOptRapidCommit.h"
-#include "SrvOptGeneric.h"
+#include "OptGeneric.h"
 #include "SrvOptLQ.h"
 #include "SrvOptTA.h"
 #include "SrvCfgOptions.h"
-
-// --- options ---
 #include "SrvOptDNSServers.h"
 #include "SrvOptDomainName.h"
 #include "SrvOptNTPServers.h"
@@ -77,21 +69,20 @@
  * @param msgType 
  * @param transID 
  */
-TSrvMsg::TSrvMsg(SmartPtr<TSrvIfaceMgr> IfaceMgr, 
-                 SmartPtr<TSrvTransMgr> TransMgr, 
-                 SmartPtr<TSrvCfgMgr> CfgMgr,
-                 SmartPtr<TSrvAddrMgr> AddrMgr,
-                 int iface, SmartPtr<TIPv6Addr> addr, int msgType, long transID)
-                 :TMsg(iface, addr, msgType, transID)
+TSrvMsg::TSrvMsg(int iface, SPtr<TIPv6Addr> addr, int msgType, long transID)
+    :TMsg(iface, addr, msgType, transID)
 {
-    setAttribs(IfaceMgr,TransMgr,CfgMgr,AddrMgr);
     this->Relays = 0;
 
-
 #ifndef MOD_DISABLE_AUTH
-    this->DigestType = CfgMgr->getDigest();
-    this->AuthKeys = CfgMgr->AuthKeys;
+    this->DigestType = SrvCfgMgr().getDigest();
+    this->AuthKeys = SrvCfgMgr().AuthKeys;
 #endif
+
+    FirstTimeStamp = now();
+    this->MRT=0;
+    KeyGenNonce = NULL;
+    KeyGenNonceLen = 0;
 }
 
 /** 
@@ -107,21 +98,21 @@ TSrvMsg::TSrvMsg(SmartPtr<TSrvIfaceMgr> IfaceMgr,
  * @param buf 
  * @param bufSize 
  */
-TSrvMsg::TSrvMsg(SmartPtr<TSrvIfaceMgr> IfaceMgr, 
-                 SmartPtr<TSrvTransMgr> TransMgr, 
-                 SmartPtr<TSrvCfgMgr> CfgMgr,
-                 SmartPtr<TSrvAddrMgr> AddrMgr,
-                 int iface,  SmartPtr<TIPv6Addr> addr,
+TSrvMsg::TSrvMsg(int iface,  SPtr<TIPv6Addr> addr,
                  char* buf,  int bufSize)
-                 :TMsg(iface, addr, buf, bufSize)
+    :TMsg(iface, addr, buf, bufSize)
 {
-    setAttribs(IfaceMgr,TransMgr,CfgMgr,AddrMgr);
     this->Relays = 0;
 
 #ifndef MOD_DISABLE_AUTH
-    this->AuthKeys = CfgMgr->AuthKeys;
-    this->DigestType = CfgMgr->getDigest();
+    this->AuthKeys = SrvCfgMgr().AuthKeys;
+    this->DigestType = SrvCfgMgr().getDigest();
 #endif
+
+    FirstTimeStamp = now();
+    this->MRT=0;
+    KeyGenNonce = NULL;
+    KeyGenNonceLen = 0;
 	
     int pos=0;
     while (pos<bufSize)	{
@@ -145,7 +136,7 @@ TSrvMsg::TSrvMsg(SmartPtr<TSrvIfaceMgr> IfaceMgr,
 	    return;
 	}
 
-        SmartPtr<TOpt> ptr;
+        SPtr<TOpt> ptr;
 
 	if (!allowOptInMsg(MsgType,code)) {
 	    Log(Warning) << "Option " << code << " not allowed in message type="<< MsgType <<". Option ignored." << LogEnd;
@@ -185,7 +176,7 @@ TSrvMsg::TSrvMsg(SmartPtr<TSrvIfaceMgr> IfaceMgr,
 	    ptr = new TSrvOptStatusCode(buf+pos,length,this);
 	    break;
 	case OPTION_RAPID_COMMIT:
-	    ptr = new TSrvOptRapidCommit(buf+pos,length,this);
+	    ptr = new TOptEmpty(code, buf+pos,length,this);
 	    break;
 	case OPTION_DNS_SERVERS:
 	    ptr = new TSrvOptDNSServers(buf+pos,length,this);
@@ -236,7 +227,7 @@ TSrvMsg::TSrvMsg(SmartPtr<TSrvIfaceMgr> IfaceMgr,
 
 #ifndef MOD_DISABLE_AUTH
 	case OPTION_AAAAUTH:
-	    if (SrvCfgMgr->getDigest() != DIGEST_NONE) {
+	    if (SrvCfgMgr().getDigest() != DIGEST_NONE) {
 		this->DigestType = DIGEST_HMAC_SHA1;
 		ptr = new TSrvOptAAAAuthentication(buf+pos, length, this);
 	    }
@@ -245,13 +236,13 @@ TSrvMsg::TSrvMsg(SmartPtr<TSrvIfaceMgr> IfaceMgr,
 	    Log(Warning) << "Option OPTION_KEYGEN received by server is invalid, ignoring." << LogEnd;
 	    break;
 	case OPTION_AUTH:
-	    if (SrvCfgMgr->getDigest() != DIGEST_NONE) {
-		this->DigestType = SrvCfgMgr->getDigest();
+	    if (SrvCfgMgr().getDigest() != DIGEST_NONE) {
+		this->DigestType = SrvCfgMgr().getDigest();
 		
 		ptr = new TSrvOptAuthentication(buf+pos, length, this);
-		SmartPtr<TOptDUID> optDUID = (SmartPtr<TOptDUID>)this->getOption(OPTION_CLIENTID);
+		SPtr<TOptDUID> optDUID = (SPtr<TOptDUID>)this->getOption(OPTION_CLIENTID);
 		if (optDUID) {
-		    SmartPtr<TAddrClient> client = SrvAddrMgr->getClient(optDUID->getDUID());
+		    SPtr<TAddrClient> client = SrvAddrMgr().getClient(optDUID->getDUID());
 		    if (client)
 			client->setSPI(SPI);
 		}
@@ -260,7 +251,7 @@ TSrvMsg::TSrvMsg(SmartPtr<TSrvIfaceMgr> IfaceMgr,
 	    
         break;
 	case OPTION_VENDOR_OPTS:
-	    ptr = new TSrvOptVendorSpec(buf+pos, length, this);
+	    ptr = new TOptVendorSpecInfo(code, buf+pos, length, this);
 	    break;
 	case OPTION_RECONF_ACCEPT:
 	case OPTION_USER_CLASS:
@@ -272,7 +263,7 @@ TSrvMsg::TSrvMsg(SmartPtr<TSrvIfaceMgr> IfaceMgr,
 	    break;
 	}
 	if ( (ptr) && (ptr->isValid()) )
-	    Options.append( ptr );
+	    Options.push_back( ptr );
 	else
 	    Log(Warning) << "Option type " << code << " invalid. Option ignored." << LogEnd;
         pos+=length;
@@ -280,21 +271,6 @@ TSrvMsg::TSrvMsg(SmartPtr<TSrvIfaceMgr> IfaceMgr,
 
 }
 
-void TSrvMsg::setAttribs(SmartPtr<TSrvIfaceMgr> IfaceMgr, 
-                         SmartPtr<TSrvTransMgr> TransMgr, 
-                         SmartPtr<TSrvCfgMgr> CfgMgr,
-                         SmartPtr<TSrvAddrMgr> AddrMgr)
-{
-    SrvTransMgr=TransMgr;	
-    SrvIfaceMgr=IfaceMgr;	
-    SrvCfgMgr=CfgMgr;
-    SrvAddrMgr=AddrMgr;
-    FirstTimeStamp = now();
-    this->MRT=0;
-    KeyGenNonce = NULL;
-    KeyGenNonceLen = 0;
-}
-
 void TSrvMsg::doDuties() {
     if ( !this->getTimeout() )
         this->IsDone = true;
@@ -307,11 +283,11 @@ unsigned long TSrvMsg::getTimeout() {
         return 0;
 }
 
-void TSrvMsg::addRelayInfo(SmartPtr<TIPv6Addr> linkAddr,
-			   SmartPtr<TIPv6Addr> peerAddr,
+void TSrvMsg::addRelayInfo(SPtr<TIPv6Addr> linkAddr,
+			   SPtr<TIPv6Addr> peerAddr,
 			   int hop,
-			   SmartPtr<TSrvOptInterfaceID> interfaceID,
-                           List(TSrvOptGeneric) echolist) {
+			   SPtr<TSrvOptInterfaceID> interfaceID,
+                           List(TOptGeneric) echolist) {
     this->LinkAddrTbl[this->Relays] = linkAddr;
     this->PeerAddrTbl[this->Relays] = peerAddr;
     this->HopTbl[this->Relays]      = hop;
@@ -330,13 +306,13 @@ void TSrvMsg::send()
     int offset = 0;
     int port;
 
-    SPtr<TSrvOptGeneric> gen;
-    SmartPtr<TSrvIfaceIface> ptrIface;
-    SmartPtr<TSrvIfaceIface> under;
-    ptrIface = (Ptr*) SrvIfaceMgr->getIfaceByID(this->Iface);
+    SPtr<TOptGeneric> gen;
+    SPtr<TSrvIfaceIface> ptrIface;
+    SPtr<TSrvIfaceIface> under;
+    ptrIface = (Ptr*) SrvIfaceMgr().getIfaceByID(this->Iface);
     Log(Notice) << "Sending " << this->getName() << " on " << ptrIface->getName() << "/" << this->Iface
 		<< hex << ",transID=0x" << this->getTransID() << dec << ", opts:";
-    SmartPtr<TOpt> ptrOpt;
+    SPtr<TOpt> ptrOpt;
     this->firstOption();
     while (ptrOpt = this->getOption() )
         Log(Cont) << " " << ptrOpt->getOptType();
@@ -355,7 +331,7 @@ void TSrvMsg::send()
 	len[Relays-1]=this->getSize();
 	for (int i=this->Relays-1; i>0; i--) {
 	    len[i-1]= len[i] + 38; // 34 bytes (relay header) + 4 bytes (relay-msg option header)
-	    if (this->InterfaceIDTbl[i] && (SrvCfgMgr->getInterfaceIDOrder()!=SRV_IFACE_ID_ORDER_NONE)) {
+	    if (this->InterfaceIDTbl[i] && (SrvCfgMgr().getInterfaceIDOrder()!=SRV_IFACE_ID_ORDER_NONE)) {
 		len[i-1]+=this->InterfaceIDTbl[i]->getSize();
 
 		EchoListTbl[i].first();
@@ -367,7 +343,7 @@ void TSrvMsg::send()
 	}
 
 	// recursive storeSelf
-	offset += storeSelfRelay(buf, 0, SrvCfgMgr->getInterfaceIDOrder() );
+	offset += storeSelfRelay(buf, 0, SrvCfgMgr().getInterfaceIDOrder() );
 
 	// check if there are underlaying interfaces
 	for (int i=0; i < this->Relays; i++) {
@@ -384,14 +360,24 @@ void TSrvMsg::send()
     } else {
 	offset += this->storeSelf(buf+offset);
     }
-    this->SrvIfaceMgr->send(ptrIface->getID(), buf, offset, this->PeerAddr, port);
+    SrvIfaceMgr().send(ptrIface->getID(), buf, offset, this->PeerAddr, port);
 }
 
 void TSrvMsg::copyRemoteID(SPtr<TSrvMsg> q) {
   this->RemoteID = q->getRemoteID();
 }
 
-void TSrvMsg::copyRelayInfo(SmartPtr<TSrvMsg> q) {
+bool TSrvMsg::copyClientID(SPtr<TMsg> donor) {
+    SPtr<TOpt> x = donor->getOption(OPTION_CLIENTID);
+    if (x) {
+	SPtr<TOptDUID> optDuid = (Ptr*) x;
+	ClientDUID = optDuid->getDUID();
+	return true;
+    }
+    return false;
+}
+
+void TSrvMsg::copyRelayInfo(SPtr<TSrvMsg> q) {
     this->Relays = q->Relays;
     for (int i=0; i < this->Relays; i++) {
 	this->LinkAddrTbl[i]   = q->LinkAddrTbl[i];
@@ -432,11 +418,11 @@ int TSrvMsg::storeSelfRelay(char * buf, int relayDepth, ESrvIfaceIdOrder order)
 	}
     }
 
-    *(short*)(buf+offset) = htons(OPTION_RELAY_MSG);
-    offset+=2;
-    *(short*)(buf+offset) = htons(len[relayDepth]);
-    offset+=2;
-    
+    writeUint16((buf+offset), OPTION_RELAY_MSG);
+    offset += sizeof(uint16_t);
+    writeUint16((buf+offset), len[relayDepth]);
+    offset += sizeof(uint16_t);
+
     offset += storeSelfRelay(buf+offset, relayDepth+1, order);
 
     if (order == SRV_IFACE_ID_ORDER_AFTER)
@@ -447,7 +433,7 @@ int TSrvMsg::storeSelfRelay(char * buf, int relayDepth, ESrvIfaceIdOrder order)
 	}
     }
 
-    SPtr<TSrvOptGeneric> gen;
+    SPtr<TOptGeneric> gen;
     EchoListTbl[relayDepth].first();
     while (gen = EchoListTbl[relayDepth].get()) {
 	Log(Debug) << "Echoing back option " << gen->getOptType() << ", length " << gen->getSize() << LogEnd;
@@ -459,7 +445,7 @@ int TSrvMsg::storeSelfRelay(char * buf, int relayDepth, ESrvIfaceIdOrder order)
 }
 
 
-void TSrvMsg::copyAAASPI(SmartPtr<TSrvMsg> q) {
+void TSrvMsg::copyAAASPI(SPtr<TSrvMsg> q) {
 #ifndef MOD_DISABLE_AUTH
     this->AAASPI = q->getAAASPI();
     this->SPI = q->getSPI();
@@ -471,7 +457,7 @@ void TSrvMsg::copyAAASPI(SmartPtr<TSrvMsg> q) {
  * this function appends authentication option
  * 
  */
-void TSrvMsg::appendAuthenticationOption(SmartPtr<TDUID> duid)
+void TSrvMsg::appendAuthenticationOption(SPtr<TDUID> duid)
 {
 
 #ifndef MOD_DISABLE_AUTH
@@ -480,7 +466,7 @@ void TSrvMsg::appendAuthenticationOption(SmartPtr<TDUID> duid)
         return;
     }
 
-    DigestType = SrvCfgMgr->getDigest();
+    DigestType = SrvCfgMgr().getDigest();
     if (DigestType == DIGEST_NONE) {
         // Log(Debug) << "Auth: Authentication is disabled." << LogEnd;
         return;
@@ -489,7 +475,7 @@ void TSrvMsg::appendAuthenticationOption(SmartPtr<TDUID> duid)
     Log(Debug) << "Auth: Setting DigestType to: " << this->DigestType << LogEnd;
 
     if (!getOption(OPTION_AUTH)) {
-        SmartPtr<TAddrClient> client = SrvAddrMgr->getClient(duid);
+        SPtr<TAddrClient> client = SrvAddrMgr().getClient(duid);
         if (client && !client->getSPI() && this->getSPI())
             client->setSPI(this->getSPI());
 
@@ -497,11 +483,44 @@ void TSrvMsg::appendAuthenticationOption(SmartPtr<TDUID> duid)
             this->ReplayDetection = client->getNextReplayDetectionSent();
         else
             this->ReplayDetection = 1;
-        Options.append(new TSrvOptAuthentication(this));
+        Options.push_back(new TSrvOptAuthentication(this));
     }
 #endif
 }
 
+bool TSrvMsg::appendMandatoryOptions(SPtr<TSrvOptOptionRequest> oro, bool clientID /* =true */)
+{
+    // include our DUID (Server ID)
+    SPtr<TSrvOptServerIdentifier> ptrSrvID;
+    ptrSrvID = new TSrvOptServerIdentifier(SrvCfgMgr().getDUID(),this);
+    Options.push_back((Ptr*)ptrSrvID);
+    oro->delOption(OPTION_SERVERID);
+
+    // include his DUID (Client ID)
+    if (clientID && ClientDUID) {
+	SPtr<TOptDUID> clientDuid = new TOptDUID(OPTION_CLIENTID, ClientDUID, this);
+	Options.push_back( (Ptr*)clientDuid);
+    }
+
+    // ... and our preference
+    SPtr<TSrvOptPreference> ptrPreference;
+    unsigned char preference = SrvCfgMgr().getIfaceByID(Iface)->getPreference();
+    Log(Debug) << "Preference set to " << (int)preference << "." << LogEnd;
+    ptrPreference = new TSrvOptPreference(preference,this);
+    Options.push_back((Ptr*)ptrPreference);
+    oro->delOption(OPTION_PREFERENCE);
+
+    // does this server support unicast?
+    SPtr<TIPv6Addr> unicastAddr = SrvCfgMgr().getIfaceByID(Iface)->getUnicast();
+    if (unicastAddr) {
+	SPtr<TSrvOptServerUnicast> optUnicast = new TSrvOptServerUnicast(unicastAddr, this);
+	Options.push_back((Ptr*)optUnicast);
+	oro->delOption(OPTION_UNICAST);
+    }
+    
+    return true;
+}
+
 /** 
  * this function appends all standard options
  * 
@@ -512,15 +531,15 @@ void TSrvMsg::appendAuthenticationOption(SmartPtr<TDUID> duid)
  * 
  * @return true, if any options (conveying configuration paramter) has been appended
  */
-bool TSrvMsg::appendRequestedOptions(SmartPtr<TDUID> duid, SmartPtr<TIPv6Addr> addr, 
-				     int iface, SmartPtr<TSrvOptOptionRequest> reqOpts)
+bool TSrvMsg::appendRequestedOptions(SPtr<TDUID> duid, SPtr<TIPv6Addr> addr, 
+				     int iface, SPtr<TSrvOptOptionRequest> reqOpts)
 {
     bool newOptionAssigned = false;
     // client didn't want any option? Or maybe we're not supporting this client?
-    if (!reqOpts->count() || !SrvCfgMgr->isClntSupported(duid,addr,iface))
+    if (!reqOpts->count() || !SrvCfgMgr().isClntSupported(duid,addr,iface))
 	return false;
 
-    SmartPtr<TSrvCfgIface>  ptrIface=SrvCfgMgr->getIfaceByID(iface);
+    SPtr<TSrvCfgIface>  ptrIface=SrvCfgMgr().getIfaceByID(iface);
     if (!ptrIface) {
 	Log(Error) << "Unable to find interface (ifindex=" << iface << "). Something is wrong." << LogEnd;
 	return false;
@@ -530,67 +549,67 @@ bool TSrvMsg::appendRequestedOptions(SmartPtr<TDUID> duid, SmartPtr<TIPv6Addr> a
 
     // --- option: DNS resolvers ---
     if ( reqOpts->isOption(OPTION_DNS_SERVERS) && ptrIface->supportDNSServer() ) {
-	SmartPtr<TSrvOptDNSServers> optDNS;
+	SPtr<TSrvOptDNSServers> optDNS;
 	if (ex && ex->supportDNSServer())
 	    optDNS = new TSrvOptDNSServers(*ex->getDNSServerLst(), this);
 	else
 	    optDNS = new TSrvOptDNSServers(*ptrIface->getDNSServerLst(),this);
-	Options.append((Ptr*)optDNS);
+	Options.push_back((Ptr*)optDNS);
 	newOptionAssigned = true;
     };
 
     // --- option: DOMAIN LIST ---
     if ( reqOpts->isOption(OPTION_DOMAIN_LIST) && ptrIface->supportDomain() ) {
-	SmartPtr<TSrvOptDomainName> optDomain;
+	SPtr<TSrvOptDomainName> optDomain;
 	if (ex && ex->supportDomain())
 	    optDomain = new TSrvOptDomainName(*ex->getDomainLst(),this);
 	else
 	    optDomain = new TSrvOptDomainName(*ptrIface->getDomainLst(),this);
-	Options.append((Ptr*)optDomain);
+	Options.push_back((Ptr*)optDomain);
 	newOptionAssigned = true;
     };
     
     // --- option: NTP servers ---
     if ( reqOpts->isOption(OPTION_SNTP_SERVERS) && ptrIface->supportNTPServer() ) {
-	SmartPtr<TSrvOptNTPServers> optNTP;
+	SPtr<TSrvOptNTPServers> optNTP;
 	if (ex && ex->supportNTPServer())
 	    optNTP = new TSrvOptNTPServers(*ex->getNTPServerLst(),this);
 	else
 	    optNTP = new TSrvOptNTPServers(*ptrIface->getNTPServerLst(),this);
-	Options.append((Ptr*)optNTP);
+	Options.push_back((Ptr*)optNTP);
 	newOptionAssigned = true;
     };
     
     // --- option: TIMEZONE --- 
     if ( reqOpts->isOption(OPTION_NEW_TZDB_TIMEZONE) && ptrIface->supportTimezone() ) {
-	SmartPtr<TSrvOptTimeZone> optTimezone;
+	SPtr<TSrvOptTimeZone> optTimezone;
 	if (ex && ex->supportTimezone())
 	    optTimezone = new TSrvOptTimeZone(ex->getTimezone(),this);
 	else
 	    optTimezone = new TSrvOptTimeZone(ptrIface->getTimezone(),this);
-	Options.append((Ptr*)optTimezone);
+	Options.push_back((Ptr*)optTimezone);
 	newOptionAssigned = true;
     };
 
     // --- option: SIP SERVERS ---
     if ( reqOpts->isOption(OPTION_SIP_SERVER_A) && ptrIface->supportSIPServer() ) {
-	SmartPtr<TSrvOptSIPServers> optSIPServer;
+	SPtr<TSrvOptSIPServers> optSIPServer;
 	if (ex && ex->supportSIPServer())
 	    optSIPServer = new TSrvOptSIPServers(*ex->getSIPServerLst(),this);
 	else
 	    optSIPServer = new TSrvOptSIPServers(*ptrIface->getSIPServerLst(),this);
-	Options.append((Ptr*)optSIPServer);
+	Options.push_back((Ptr*)optSIPServer);
 	newOptionAssigned = true;
     };
 
     // --- option: SIP DOMAINS ---
     if ( reqOpts->isOption(OPTION_SIP_SERVER_D) && ptrIface->supportSIPDomain() ) {
-	SmartPtr<TSrvOptSIPDomain> optSIPDomain;
+	SPtr<TSrvOptSIPDomain> optSIPDomain;
 	if (ex && ex->supportSIPDomain())
 	    optSIPDomain= new TSrvOptSIPDomain(*ex->getSIPDomainLst(),this);
 	else
 	    optSIPDomain= new TSrvOptSIPDomain(*ptrIface->getSIPDomainLst(),this);
-	Options.append((Ptr*)optSIPDomain);
+	Options.push_back((Ptr*)optSIPDomain);
 	newOptionAssigned = true;
     };
 
@@ -599,50 +618,50 @@ bool TSrvMsg::appendRequestedOptions(SmartPtr<TDUID> duid, SmartPtr<TIPv6Addr> a
 
     // --- option: NIS SERVERS ---
     if ( reqOpts->isOption(OPTION_NIS_SERVERS) && ptrIface->supportNISServer() ) {
-	SmartPtr<TSrvOptNISServers> opt;
+	SPtr<TSrvOptNISServers> opt;
 	if (ex && ex->supportNISServer())
 	    opt = new TSrvOptNISServers(*ex->getNISServerLst(),this);
 	else
 	    opt = new TSrvOptNISServers(*ptrIface->getNISServerLst(),this);
-	Options.append((Ptr*)opt);
+	Options.push_back((Ptr*)opt);
 	newOptionAssigned = true;
     };
 
     // --- option: NIS DOMAIN ---
     if ( reqOpts->isOption(OPTION_NIS_DOMAIN_NAME) && ptrIface->supportNISDomain() ) {
-	SmartPtr<TSrvOptNISDomain> opt;
+	SPtr<TSrvOptNISDomain> opt;
 	if (ex && ex->supportNISDomain())
 	    opt = new TSrvOptNISDomain(ex->getNISDomain(),this);
 	else
 	    opt = new TSrvOptNISDomain(ptrIface->getNISDomain(),this);
-	Options.append((Ptr*)opt);
+	Options.push_back((Ptr*)opt);
 	newOptionAssigned = true;
     };
 
     // --- option: NISP SERVERS ---
     if ( reqOpts->isOption(OPTION_NISP_SERVERS) && ptrIface->supportNISPServer() ) {
-	SmartPtr<TSrvOptNISPServers> opt;
+	SPtr<TSrvOptNISPServers> opt;
 	if (ex && ex->supportNISPServer())
 	    opt = new TSrvOptNISPServers(*ex->getNISPServerLst(),this);
 	else
 	    opt = new TSrvOptNISPServers(*ptrIface->getNISPServerLst(),this);
-	Options.append((Ptr*) opt);
+	Options.push_back((Ptr*) opt);
 	newOptionAssigned = true;
     };
 
     // --- option: NISP DOMAIN ---
     if ( reqOpts->isOption(OPTION_NISP_DOMAIN_NAME) && ptrIface->supportNISPDomain() ) {
-	SmartPtr<TSrvOptNISPDomain> opt;
+	SPtr<TSrvOptNISPDomain> opt;
 	if (ex && ex->supportNISPDomain())
 	    opt = new TSrvOptNISPDomain(ex->getNISPDomain(), this);
 	else
 	    opt = new TSrvOptNISPDomain(ptrIface->getNISPDomain(), this);
-	Options.append((Ptr*)opt);
+	Options.push_back((Ptr*)opt);
 	newOptionAssigned = true;
     };
 
     // --- option: VENDOR SPEC ---
-    if ( reqOpts->isOption(OPTION_VENDOR_OPTS) && ptrIface->supportVendorSpec()) {
+    if ( reqOpts->isOption(OPTION_VENDOR_OPTS)) {
 	if (appendVendorSpec(duid, iface, 0, reqOpts))
 	    newOptionAssigned = true;
     }
@@ -650,43 +669,66 @@ bool TSrvMsg::appendRequestedOptions(SmartPtr<TDUID> duid, SmartPtr<TIPv6Addr> a
     // --- option: INFORMATION_REFRESH_TIME ---
     // this option should be checked last 
     if ( newOptionAssigned && ptrIface->supportLifetime() ) {
-	SmartPtr<TSrvOptLifetime> optLifetime;
+	SPtr<TSrvOptLifetime> optLifetime;
 	if (ex && ex->supportLifetime())
 	    optLifetime = new TSrvOptLifetime(ex->getLifetime(), this);
 	else
 	    optLifetime = new TSrvOptLifetime(ptrIface->getLifetime(), this);
-	Options.append( (Ptr*)optLifetime);
+	Options.push_back( (Ptr*)optLifetime);
 	newOptionAssigned = true;
     }
 
-    // --- option: extra options ---
-    List(TSrvOptGeneric) generics = ptrIface->getExtraOptions();
+    // --- option: forced options first ---
+    TOptList extraOpts; // possible additional options
+    TOptList forcedOpts; // forced (asked for or not, will send them anyway)
+    
+    if (ex) {
+        extraOpts = ex->getExtraOptions();
+        forcedOpts = ex->getForcedOptions();
+    } 
 
-    SPtr<TSrvOptGeneric> gen;
-    generics.first();
-    while (gen = generics.get())
+    if (!ex || !extraOpts.size())
+        extraOpts = ptrIface->getExtraOptions();
+    
+    if (!ex || !forcedOpts.size())
+        forcedOpts = ptrIface->getForcedOptions();
+
+    for (TOptList::iterator gen = forcedOpts.begin(); gen!=forcedOpts.end(); ++gen)
     {
-	Log(Debug) << "Experimental: Appending extra option " << gen->getSize() << LogEnd;
-	Options.append( (Ptr*) gen);
+	Log(Debug) << "Appending mandatory extra option " << (*gen)->getOptType() 
+		   << " (" << (*gen)->getSize() << ")" << LogEnd;
+	Options.push_back( (Ptr*) *gen);
+        reqOpts->delOption( (*gen)->getOptType() );
 	newOptionAssigned = true;
     }
 
+    for (TOptList::iterator gen = extraOpts.begin(); gen!=extraOpts.end(); ++gen)
+    {
+	if (reqOpts->isOption( (*gen)->getOptType()))
+	{
+	    Log(Debug) << "Appending requested extra option " << (*gen)->getOptType() 
+		       << " (" << (*gen)->getSize() << ")" << LogEnd;
+	    Options.push_back( (Ptr*) *gen);
+	    newOptionAssigned = true;
+	}
+    }
+
     // --- option: KEYGEN ---
 #ifndef MOD_DISABLE_AUTH
-    if ( reqOpts->isOption(OPTION_KEYGEN) && SrvCfgMgr->getDigest() != DIGEST_NONE ) { // && this->MsgType == ADVERTISE_MSG ) {
-        	SmartPtr<TSrvOptKeyGeneration> optKeyGeneration = new TSrvOptKeyGeneration(this);
-        	Options.append( (Ptr*)optKeyGeneration);
+    if ( reqOpts->isOption(OPTION_KEYGEN) && SrvCfgMgr().getDigest() != DIGEST_NONE ) 
+    { // && this->MsgType == ADVERTISE_MSG ) {
+        SPtr<TSrvOptKeyGeneration> optKeyGeneration = new TSrvOptKeyGeneration(this);
+        Options.push_back( (Ptr*)optKeyGeneration);
     }
 #endif
 
-
     return newOptionAssigned;
 }
 
 /**
  * this function prints all options specified in the ORO option
  */
-string TSrvMsg::showRequestedOptions(SmartPtr<TSrvOptOptionRequest> oro) {
+string TSrvMsg::showRequestedOptions(SPtr<TSrvOptOptionRequest> oro) {
     ostringstream x;
     int i = oro->count();
     x << i << " opts";
@@ -699,21 +741,22 @@ string TSrvMsg::showRequestedOptions(SmartPtr<TSrvOptOptionRequest> oro) {
 }
 
 /** 
- * This function creates FQDN option and executes DNS Update procedure (if necessary)
+ * creates FQDN option and executes DNS Update procedure (if necessary)
  * 
- * @param requestFQDN 
- * @param clntDuid 
- * @param clntAddr 
+ * @param requestFQDN  requested Fully Qualified Domain Name
+ * @param clntDuid     client DUID
+ * @param clntAddr     client address
+ * @param hint         hint used to get name (it may or may not be used)
  * @param doRealUpdate - should the real update be performed (for example if response for
  *                       SOLICIT is prepare, this should be set to false)
  * 
- * @return 
+ * @return FQDN option
  */
 SPtr<TSrvOptFQDN> TSrvMsg::prepareFQDN(SPtr<TSrvOptFQDN> requestFQDN, SPtr<TDUID> clntDuid, 
 				       SPtr<TIPv6Addr> clntAddr, string hint, bool doRealUpdate) {
 
-    SmartPtr<TSrvOptFQDN> optFQDN;
-    SmartPtr<TSrvCfgIface> ptrIface = SrvCfgMgr->getIfaceByID( this->Iface );
+    SPtr<TSrvOptFQDN> optFQDN;
+    SPtr<TSrvCfgIface> ptrIface = SrvCfgMgr().getIfaceByID( this->Iface );
     if (!ptrIface) {
 	Log(Crit) << "Msg received through not configured interface. "
 	    "Somebody call an exorcist!" << LogEnd;
@@ -725,12 +768,12 @@ SPtr<TSrvOptFQDN> TSrvMsg::prepareFQDN(SPtr<TSrvOptFQDN> requestFQDN, SPtr<TDUID
 	Log(Error) << "FQDN is not defined on " << ptrIface->getFullName() << " interface." << LogEnd;
 	return 0;
     }
-
+    
     if (!ptrIface->supportDNSServer()) {
 	Log(Error) << "DNS server is not supported on " << ptrIface->getFullName() << " interface. DNS Update aborted." << LogEnd;
 	return 0;
     }
-
+    
     Log(Debug) << "Requesting FQDN for client with DUID=" << clntDuid->getPlain() << ", addr=" << clntAddr->getPlain() << LogEnd;
 	
     SPtr<TFQDN> fqdn = ptrIface->getFQDNName(clntDuid,clntAddr, hint);
@@ -746,13 +789,13 @@ SPtr<TSrvOptFQDN> TSrvMsg::prepareFQDN(SPtr<TSrvOptFQDN> requestFQDN, SPtr<TDUID
     string fqdnName = fqdn->getName();
 
     if (requestFQDN->getNFlag()) {
-	Log(Notice) << "FQDN: No DNS Update required." << LogEnd;
-	return optFQDN;
+	      Log(Notice) << "FQDN: No DNS Update required." << LogEnd;
+	      return optFQDN;
     }
 
     if (!doRealUpdate) {
-	Log(Debug) << "FQDN: Skipping update (probably a SOLICIT message)." << LogEnd;
-	return optFQDN;
+	      Log(Debug) << "FQDN: Skipping update (probably a SOLICIT message)." << LogEnd;
+	      return optFQDN;
     }
 
     fqdn->setUsed(true);
@@ -763,70 +806,85 @@ SPtr<TSrvOptFQDN> TSrvMsg::prepareFQDN(SPtr<TSrvOptFQDN> requestFQDN, SPtr<TDUID
     if ( FQDNMode==1 || FQDNMode==2 ) {
 	Log(Debug) << "FQDN: Server configuration allow DNS updates for " << clntDuid->getPlain() << LogEnd;
 	
-	if (FQDNMode == 1) optFQDN->setSFlag(false);
-	else if (FQDNMode == 2)  optFQDN->setSFlag(true); // letting client update his AAAA
+	if (FQDNMode == 1) 
+	    optFQDN->setSFlag(false);
+	else 
+	    if (FQDNMode == 2) 
+		optFQDN->setSFlag(true); // letting client update his AAAA
 	// Setting the O Flag correctly according to the difference between O flags
 	optFQDN->setOFlag(requestFQDN->getSFlag() /*xor 0*/);
-	// Here we check if all parameters are set, and do the DNS update if possible
-	List(TIPv6Addr) DNSSrvLst = *ptrIface->getDNSServerLst();
-	SmartPtr<TIPv6Addr> DNSAddr;
 	
-	// For the moment, we just take the first DNS entry.
-	DNSSrvLst.first();
-	DNSAddr = DNSSrvLst.get();
-	
-	SmartPtr<TAddrClient> ptrAddrClient = SrvAddrMgr->getClient(clntDuid);	
+	SPtr<TIPv6Addr> DNSAddr = SrvCfgMgr().getDDNSAddress(Iface);
+	if (!DNSAddr) {
+	    Log(Error) << "DDNS: DNS Update aborted. DNS server address is not specified." << LogEnd;
+	    return 0;
+	}
+      	
+	SPtr<TAddrClient> ptrAddrClient = SrvAddrMgr().getClient(clntDuid);	
 	if (!ptrAddrClient) { 
 	    Log(Warning) << "Unable to find client."; 
 	    return 0;
 	}
 	ptrAddrClient->firstIA();
-	SmartPtr<TAddrIA> ptrAddrIA = ptrAddrClient->getIA();
+	SPtr<TAddrIA> ptrAddrIA = ptrAddrClient->getIA();
 	if (!ptrAddrIA) { 
 	    Log(Warning) << "Client does not have any addresses assigned." << LogEnd; 
 	    return 0;
 	}
 	ptrAddrIA->firstAddr();
-	SmartPtr<TAddrAddr> addr = ptrAddrIA->getAddr();
-	SmartPtr<TIPv6Addr> IPv6Addr = addr->get();
-	
-	Log(Notice) << "FQDN: About to perform DNS Update: DNS server=" << *DNSAddr << ", IP=" << *IPv6Addr << " and FQDN=" 
-                    << fqdnName << LogEnd;
+	SPtr<TAddrAddr> addr = ptrAddrIA->getAddr();
+	SPtr<TIPv6Addr> IPv6Addr = addr->get();
 	
+	Log(Notice) << "FQDN: About to perform DNS Update: DNS server=" << *DNSAddr << ", IP=" 
+		    << *IPv6Addr << " and FQDN=" << fqdnName << LogEnd;
+      	
 	//Test for DNS update
 	char zoneroot[128];
 	doRevDnsZoneRoot(IPv6Addr->getAddr(), zoneroot, ptrIface->getRevDNSZoneRootLength());
 #ifndef MOD_SRV_DISABLE_DNSUPDATE
+
+	// that's ugly but required. Otherwise we would have to include CfgMgr.h in DNSUpdate.h
+	// and that would include both poslib and Dibbler headers in one place. Universe would implode then.
+	TCfgMgr::DNSUpdateProtocol proto = SrvCfgMgr().getDDNSProtocol();
+	DNSUpdate::DnsUpdateProtocol proto2 = DNSUpdate::DNSUPDATE_TCP;
+	if (proto == TCfgMgr::DNSUPDATE_UDP)
+	    proto2 = DNSUpdate::DNSUPDATE_UDP;
+	if (proto == TCfgMgr::DNSUPDATE_ANY)
+	    proto2 = DNSUpdate::DNSUPDATE_ANY;
+	unsigned int timeout = SrvCfgMgr().getDDNSTimeout();
+	
 	if (FQDNMode==1){
 	    /* add PTR only */
 	    DnsUpdateResult result = DNSUPDATE_SKIP;
-	    DNSUpdate *act = new DNSUpdate(DNSAddr->getPlain(), zoneroot, fqdnName, IPv6Addr->getPlain(), DNSUPDATE_PTR);
-	    result = act->run();
+	    DNSUpdate *act = new DNSUpdate(DNSAddr->getPlain(), zoneroot, fqdnName, IPv6Addr->getPlain(), 
+					   DNSUPDATE_PTR, proto2);
+	    result = act->run(timeout);
 	    act->showResult(result);
 	    delete act;
 	} // fqdnMode == 1
 	else if (FQDNMode==2){
 	    DnsUpdateResult result = DNSUPDATE_SKIP;
-	    DNSUpdate *act = new DNSUpdate(DNSAddr->getPlain(), zoneroot, fqdnName, IPv6Addr->getPlain(), DNSUPDATE_PTR);
-	    result = act->run();
+	    DNSUpdate *act = new DNSUpdate(DNSAddr->getPlain(), zoneroot, fqdnName, IPv6Addr->getPlain(), 
+					   DNSUPDATE_PTR, proto2);
+	    result = act->run(timeout);
 	    act->showResult(result);
 	    delete act;
-	    
+      	    
 	    DnsUpdateResult result2 = DNSUPDATE_SKIP;
-	    DNSUpdate *act2 = new DNSUpdate(DNSAddr->getPlain(), "", fqdnName, IPv6Addr->getPlain(), DNSUPDATE_AAAA);
-	    result2 = act2->run();
+	    DNSUpdate *act2 = new DNSUpdate(DNSAddr->getPlain(), "", fqdnName, IPv6Addr->getPlain(), 
+					    DNSUPDATE_AAAA, proto2);
+	    result2 = act2->run(timeout);
 	    act2->showResult(result);
 	    delete act2;
 	} // fqdnMode == 2
-
+	
 	// regardless of the result, store the info
 	ptrAddrIA->setFQDN(fqdn);
 	ptrAddrIA->setFQDNDnsServer(DNSAddr);
 	
 #else
-	Log(Error) << "This server is compiled without DNS Update support." << LogEnd;
+      	Log(Error) << "This server is compiled without DNS Update support." << LogEnd;
 #endif
-
     } else {
 	Log(Debug) << "Server configuration does NOT allow DNS updates for " << clntDuid->getPlain() << LogEnd;
 	optFQDN->setNFlag(true);
@@ -865,12 +923,24 @@ void TSrvMsg::fqdnRelease(SPtr<TSrvCfgIface> ptrIface, SPtr<TAddrIA> ptrIA, SPtr
     char zoneroot[128];
     doRevDnsZoneRoot(clntAddr->getAddr(), zoneroot, ptrIface->getRevDNSZoneRootLength());
 
+
+    // that's ugly but required. Otherwise we would have to include CfgMgr.h in DNSUpdate.h
+    // and that would include both poslib and Dibbler headers in one place. Universe would implode then.
+    TCfgMgr::DNSUpdateProtocol proto = SrvCfgMgr().getDDNSProtocol();
+    DNSUpdate::DnsUpdateProtocol proto2 = DNSUpdate::DNSUPDATE_TCP;
+    if (proto == TCfgMgr::DNSUPDATE_UDP)
+        proto2 = DNSUpdate::DNSUPDATE_UDP;
+    if (proto == TCfgMgr::DNSUPDATE_ANY)
+        proto2 = DNSUpdate::DNSUPDATE_ANY;
+    unsigned int timeout = SrvCfgMgr().getDDNSTimeout();
+
     if (FQDNMode == DNSUPDATE_MODE_PTR){
 	/* PTR cleanup */
 	Log(Notice) << "FQDN: Attempting to clean up PTR record in DNS Server " << * dns << ", IP = " << *clntAddr 
 		    << " and FQDN=" << fqdn->getName() << LogEnd;
-	DNSUpdate *act = new DNSUpdate(dns->getPlain(), zoneroot, fqdnName, clntAddr->getPlain(), DNSUPDATE_PTR_CLEANUP);
-	result = act->run();
+	DNSUpdate *act = new DNSUpdate(dns->getPlain(), zoneroot, fqdnName, clntAddr->getPlain(), 
+                                       DNSUPDATE_PTR_CLEANUP, proto2);
+	result = act->run(timeout);
 	act->showResult(result);
 	delete act;
 	
@@ -880,16 +950,18 @@ void TSrvMsg::fqdnRelease(SPtr<TSrvCfgIface> ptrIface, SPtr<TAddrIA> ptrIA, SPtr
 	Log(Notice) << "FQDN: Attempting to clean up AAAA and PTR record in DNS Server " << * dns << ", IP = " 
 		    << *clntAddr << " and FQDN=" << fqdn->getName() << LogEnd;
 	
-	DNSUpdate *act = new DNSUpdate(dns->getPlain(), "", fqdnName, clntAddr->getPlain(), DNSUPDATE_AAAA_CLEANUP);
-	result = act->run();
+	DNSUpdate *act = new DNSUpdate(dns->getPlain(), "", fqdnName, clntAddr->getPlain(), 
+                                       DNSUPDATE_AAAA_CLEANUP, proto2);
+	result = act->run(timeout);
 	act->showResult(result);
 	delete act;
 	
 	/* PTR cleanup */
 	Log(Notice) << "FQDN: Attempting to clean up PTR record in DNS Server " << * dns << ", IP = " << *clntAddr 
 		    << " and FQDN=" << fqdn->getName() << LogEnd;
-	DNSUpdate *act2 = new DNSUpdate(dns->getPlain(), zoneroot, fqdnName, clntAddr->getPlain(), DNSUPDATE_PTR_CLEANUP);
-	result = act2->run();
+	DNSUpdate *act2 = new DNSUpdate(dns->getPlain(), zoneroot, fqdnName, clntAddr->getPlain(), 
+                                        DNSUPDATE_PTR_CLEANUP, proto2);
+	result = act2->run(timeout);
 	act2->showResult(result);
 	delete act2;
     } // fqdn mode 2 (AAAA and PTR)
@@ -901,69 +973,66 @@ bool TSrvMsg::check(bool clntIDmandatory, bool srvIDmandatory) {
 
     SPtr<TSrvOptServerIdentifier> optSrvID = (Ptr*) this->getOption(OPTION_SERVERID);
     if (optSrvID) {
-	if ( !( *(SrvCfgMgr->getDUID()) == *(optSrvID->getDUID()) ) ) {
+	if ( !( *(SrvCfgMgr().getDUID()) == *(optSrvID->getDUID()) ) ) {
 	    Log(Debug) << "Wrong ServerID value detected. This message is not for me. Message ignored." << LogEnd;
 	    return false;
 	}
     }
-
     return status;
 }
 
 bool TSrvMsg::appendVendorSpec(SPtr<TDUID> duid, int iface, int vendor, SPtr<TSrvOptOptionRequest> reqOpt)
 {
-    SmartPtr<TSrvCfgIface> ptrIface=SrvCfgMgr->getIfaceByID(iface);
+    reqOpt->delOption(OPTION_VENDOR_OPTS);
+
+    SPtr<TSrvCfgIface> ptrIface=SrvCfgMgr().getIfaceByID(iface);
     if (!ptrIface) {
 	Log(Error) << "Unable to find interface with ifindex=" << iface << LogEnd;
 	return false;
     }
-    if (!ptrIface->supportVendorSpec()) {
-	Log(Debug) << "Client requeste VendorSpec info, but is not configured on the " << ptrIface->getFullName() << " interface." << LogEnd;
-	return false;
-    }
+
+    Log(Debug) << "Client requested vendor-spec. info (vendor=" << vendor 
+               << ")." << LogEnd;
 
     SPtr<TSrvCfgOptions> ex = ptrIface->getClientException(duid, true);
-    SPtr<TSrvOptVendorSpec> v;
-    Log(Debug) << "Client requested vendor-spec. info (vendor=" << vendor << ")." << LogEnd;
-    if (ex && ex->supportVendorSpec()) {
-	v = ex->getVendorSpec(vendor);
-	if (v) {
-	    Log(Debug) << "Found (client specific) vendor-spec. info (vendor=" << v->getVendor() << ")." << LogEnd;
-	    Options.append( (Ptr*)v);
-	    reqOpt->delOption(OPTION_VENDOR_OPTS);
-	    return true;
-	}
+    SPtr<TOptVendorSpecInfo> vs;
+    List(TOptVendorSpecInfo) vsLst;
+
+    if (ex) {
+        vsLst = ex->getVendorSpecLst(vendor);
+    } else {
+        vsLst = ptrIface->getVendorSpecLst(vendor);
     }
 
-    v= ptrIface->getVendorSpec(vendor);
-    if (v) {
-	Log(Debug) << "Found vendor-spec. info (vendor=" << v->getVendor() << ")." << LogEnd;
-	Options.append( (Ptr*)v);
-	reqOpt->delOption(OPTION_VENDOR_OPTS);
-	return true;
+
+    if (!vsLst.count())
+        vsLst = ptrIface->getVendorSpecLst(vendor);
+        
+    if (vsLst.count()) {
+        vsLst.first();
+        while (vs=vsLst.get())
+        {
+            Options.push_back( (Ptr*)vs);
+        }
+        return true;
     }
 
-    Log(Debug) << "Unable to find any vendor-specific option." << LogEnd;
+    Log(Debug) << "Unable to find suitable vendor-specific info option." << LogEnd;
     return false;
 }
 
-SmartPtr<TSrvTransMgr> TSrvMsg::getSrvTransMgr()
-{
-    return this->SrvTransMgr;
-}
-
 bool TSrvMsg::validateReplayDetection() {
 
 #ifndef MOD_DISABLE_AUTH
     if (this->MsgType == SOLICIT_MSG)
         return true;
 
-    if (SrvCfgMgr->getDigest() ==  DIGEST_NONE) {
+    if (SrvCfgMgr().getDigest() ==  DIGEST_NONE) {
         // Log(Debug) << "Auth: Authentication is disabled." << LogEnd;
         return true;
     }
 
-    SmartPtr<TAddrClient> client = SrvAddrMgr->getClient(SPI);
+    SPtr<TAddrClient> client = SrvAddrMgr().getClient(SPI);
     if (!client) {
         Log(Debug) << "Auth: Unable to find client with SPI=" << SPI << "." << LogEnd;
         return true;
@@ -984,12 +1053,12 @@ bool TSrvMsg::validateReplayDetection() {
 #endif
 }
 
-void TSrvMsg::setRemoteID(SPtr<TSrvOptRemoteID> remoteID)
+void TSrvMsg::setRemoteID(SPtr<TOptVendorData> remoteID)
 {
     RemoteID = remoteID;
 }
 
-SPtr<TSrvOptRemoteID> TSrvMsg::getRemoteID()
+SPtr<TOptVendorData> TSrvMsg::getRemoteID()
 {
     return RemoteID;
 }
@@ -1014,7 +1083,7 @@ void TSrvMsg::appendStatusCode()
 		    // copy status code to root-level
 		    delOption(OPTION_STATUS_CODE);
 		    rootLevel = new TSrvOptStatusCode(optLevel->getCode(), optLevel->getText(), this);
-		    Options.append( (Ptr*) rootLevel);
+		    Options.push_back( (Ptr*) rootLevel);
 		    return;
 		}
 	    }
@@ -1029,15 +1098,27 @@ void TSrvMsg::appendStatusCode()
 
 }
 
-bool TSrvMsg::delOption(int code)
-{
-    SPtr<TOpt> opt;
-    Options.first();
-    while (opt = Options.get()) {
-	if (opt->getOptType() == code) {
-	    Options.del();
-	    return true;
-	}
+void TSrvMsg::handleDefaultOption(SPtr<TOpt> ptrOpt) {
+    int opt = ptrOpt->getOptType();
+    switch(opt)
+    {
+    case OPTION_ELAPSED_TIME :
+        break;
+    default:
+	if (!ORO->isOption(opt) && !getOption(opt))
+	    ORO->addOption(opt);
+	break;
     }
-    return false;
+}
+
+/** 
+ * finds OPTION_REQUEST OPTION in options
+ * 
+ * @param msg - parent message
+ */
+void TSrvMsg::getORO(SPtr<TMsg> msg)
+{
+    ORO = (Ptr*)msg->getOption(OPTION_ORO);
+    if (!ORO)
+        ORO = new TSrvOptOptionRequest(this);
 }
