@@ -7,15 +7,14 @@
  * released under GNU GPL v2 only licence
  */
 
+
 #include <stdlib.h>
-#ifdef WIN32
-#include <winsock2.h>
-#endif
+#include "Portable.h"
 #include "DHCPConst.h"
 #include "SrvOptClientIdentifier.h"
 
 TSrvOptClientIdentifier::TSrvOptClientIdentifier(
-    SmartPtr<TDUID> duid, TMsg* parent)
+    SPtr<TDUID> duid, TMsg* parent)
     :TOptDUID(OPTION_CLIENTID, duid, parent)
 {
 }
