@@ -8,10 +8,7 @@
  *
  * $Id: SrvOptSIPDomain.h,v 1.2 2008-08-29 00:07:37 thomson Exp $
  *
- * $Log: SrvOptSIPDomain.h,v $
- * Revision 1.2  2008-08-29 00:07:37  thomson
- * Temporary license change(GPLv2 or later -> GPLv2 only)
- *
+ * $Log: not supported by cvs2svn $
  * Revision 1.1  2004-11-02 01:30:54  thomson
  * Initial version.
  *
@@ -32,8 +29,8 @@ class TSrvOptSIPDomain : public TOptStringLst
     TSrvOptSIPDomain(List(string) domains, TMsg* parent);
     TSrvOptSIPDomain(char *buf, int bufsize, TMsg* parent);
     bool doDuties();
-    void setSrvDuid(SmartPtr<TDUID> duid);
+    void setSrvDuid(SPtr<TDUID> duid);
 private:
-    SmartPtr<TDUID> SrvDUID;
+    SPtr<TDUID> SrvDUID;
 };
 #endif
